@@ -20,44 +20,44 @@
 #include "chxj_img_conv.h"
 #include "chxj_qr_code.h"
 
-static char* chtml10_node_exchange    (Chtml10* chtml, Node* node, int indent);
-static char* chtml10_start_html_tag   (Chtml10* chtml, Node* child);
-static char* chtml10_end_html_tag     (Chtml10* chtml, Node* child);
-static char* chtml10_start_meta_tag   (Chtml10* chtml, Node* node);
-static char* chtml10_end_meta_tag     (Chtml10* chtml, Node* node);
-static char* chtml10_start_head_tag   (Chtml10* chtml, Node* node);
-static char* chtml10_end_head_tag     (Chtml10* chtml, Node* node);
-static char* chtml10_start_title_tag  (Chtml10* chtml, Node* node);
-static char* chtml10_end_title_tag    (Chtml10* chtml, Node* node);
-static char* chtml10_start_base_tag   (Chtml10* chtml, Node* node);
-static char* chtml10_end_base_tag     (Chtml10* chtml, Node* node);
-static char* chtml10_start_body_tag   (Chtml10* chtml, Node* node);
-static char* chtml10_end_body_tag     (Chtml10* chtml, Node* node);
-static char* chtml10_start_a_tag      (Chtml10* chtml, Node* node);
-static char* chtml10_end_a_tag        (Chtml10* chtml, Node* node);
-static char* chtml10_start_br_tag     (Chtml10* chtml, Node* node);
-static char* chtml10_end_br_tag       (Chtml10* chtml, Node* node);
-static char* chtml10_start_font_tag   (Chtml10* chtml, Node* node);
-static char* chtml10_end_font_tag     (Chtml10* chtml, Node* node);
-static char* chtml10_start_form_tag   (Chtml10* chtml, Node* node);
-static char* chtml10_end_form_tag     (Chtml10* chtml, Node* node);
-static char* chtml10_start_input_tag  (Chtml10* chtml, Node* node);
-static char* chtml10_end_input_tag    (Chtml10* chtml, Node* node);
-static char* chtml10_start_center_tag (Chtml10* chtml, Node* node);
-static char* chtml10_end_center_tag   (Chtml10* chtml, Node* node);
-static char* chtml10_start_hr_tag     (Chtml10* chtml, Node* node);
-static char* chtml10_end_hr_tag       (Chtml10* chtml, Node* node);
-static char* chtml10_start_img_tag    (Chtml10* chtml, Node* node);
-static char* chtml10_end_img_tag      (Chtml10* chtml, Node* node);
-static char* chtml10_start_select_tag (Chtml10* chtml, Node* node);
-static char* chtml10_end_select_tag   (Chtml10* chtml, Node* node);
-static char* chtml10_start_option_tag (Chtml10* chtml, Node* node);
-static char* chtml10_end_option_tag   (Chtml10* chtml, Node* node);
-static char* chtml10_start_div_tag    (Chtml10* chtml, Node* node);
-static char* chtml10_end_div_tag      (Chtml10* chtml, Node* node);
-static void chxj_init_chtml10(Chtml10* chtml, Doc* doc, request_rec* r, device_table* spec);
-static int chtml10_search_emoji(Chtml10* chtml, char* txt, char** rslt);
-static void chtml10_chxjif_tag(Chtml10* chtml, Node* node);
+static char* s_chtml10_node_exchange    (chtml10_t* chtml, Node* node, int indent);
+static char* s_chtml10_start_html_tag   (chtml10_t* chtml, Node* child);
+static char* s_chtml10_end_html_tag     (chtml10_t* chtml, Node* child);
+static char* s_chtml10_start_meta_tag   (chtml10_t* chtml, Node* node);
+static char* s_chtml10_end_meta_tag     (chtml10_t* chtml, Node* node);
+static char* s_chtml10_start_head_tag   (chtml10_t* chtml, Node* node);
+static char* s_chtml10_end_head_tag     (chtml10_t* chtml, Node* node);
+static char* s_chtml10_start_title_tag  (chtml10_t* chtml, Node* node);
+static char* s_chtml10_end_title_tag    (chtml10_t* chtml, Node* node);
+static char* s_chtml10_start_base_tag   (chtml10_t* chtml, Node* node);
+static char* s_chtml10_end_base_tag     (chtml10_t* chtml, Node* node);
+static char* s_chtml10_start_body_tag   (chtml10_t* chtml, Node* node);
+static char* s_chtml10_end_body_tag     (chtml10_t* chtml, Node* node);
+static char* s_chtml10_start_a_tag      (chtml10_t* chtml, Node* node);
+static char* s_chtml10_end_a_tag        (chtml10_t* chtml, Node* node);
+static char* s_chtml10_start_br_tag     (chtml10_t* chtml, Node* node);
+static char* s_chtml10_end_br_tag       (chtml10_t* chtml, Node* node);
+static char* s_chtml10_start_font_tag   (chtml10_t* chtml, Node* node);
+static char* s_chtml10_end_font_tag     (chtml10_t* chtml, Node* node);
+static char* s_chtml10_start_form_tag   (chtml10_t* chtml, Node* node);
+static char* s_chtml10_end_form_tag     (chtml10_t* chtml, Node* node);
+static char* s_chtml10_start_input_tag  (chtml10_t* chtml, Node* node);
+static char* s_chtml10_end_input_tag    (chtml10_t* chtml, Node* node);
+static char* s_chtml10_start_center_tag (chtml10_t* chtml, Node* node);
+static char* s_chtml10_end_center_tag   (chtml10_t* chtml, Node* node);
+static char* s_chtml10_start_hr_tag     (chtml10_t* chtml, Node* node);
+static char* s_chtml10_end_hr_tag       (chtml10_t* chtml, Node* node);
+static char* s_chtml10_start_img_tag    (chtml10_t* chtml, Node* node);
+static char* s_chtml10_end_img_tag      (chtml10_t* chtml, Node* node);
+static char* s_chtml10_start_select_tag (chtml10_t* chtml, Node* node);
+static char* s_chtml10_end_select_tag   (chtml10_t* chtml, Node* node);
+static char* s_chtml10_start_option_tag (chtml10_t* chtml, Node* node);
+static char* s_chtml10_end_option_tag   (chtml10_t* chtml, Node* node);
+static char* s_chtml10_start_div_tag    (chtml10_t* chtml, Node* node);
+static char* s_chtml10_end_div_tag      (chtml10_t* chtml, Node* node);
+static void  s_init_chtml10(chtml10_t* chtml, Doc* doc, request_rec* r, device_table_t* spec);
+static int   s_chtml10_search_emoji(chtml10_t* chtml, char* txt, char** rslt);
+static void  s_chtml10_chxjif_tag(chtml10_t* chtml, Node* node);
 
 
 /**
@@ -72,14 +72,14 @@ static void chtml10_chxjif_tag(Chtml10* chtml, Node* node);
 char*
 chxj_exchange_chtml10(
   request_rec* r,
-  device_table *spec,
+  device_table_t* spec,
   const char* src,
   apr_size_t srclen,
   apr_size_t *dstlen)
 {
   char*     dst = NULL;
   char*     ss;
-  Chtml10     chtml10;
+  chtml10_t     chtml10;
   Doc       doc;
 
   /*--------------------------------------------------------------------------*/
@@ -97,7 +97,7 @@ chxj_exchange_chtml10(
   /*--------------------------------------------------------------------------*/
   /* The CHTML structure is initialized.                                      */
   /*--------------------------------------------------------------------------*/
-  chxj_init_chtml10(&chtml10, &doc, r, spec);
+  s_init_chtml10(&chtml10, &doc, r, spec);
   ap_set_content_type(r, "text/html; charset=Windows-31J");
 
   /*--------------------------------------------------------------------------*/
@@ -118,7 +118,7 @@ chxj_exchange_chtml10(
   /*--------------------------------------------------------------------------*/
   /* It converts it from CHTML to CHTML.                                      */
   /*--------------------------------------------------------------------------*/
-  dst = chtml10_node_exchange(&chtml10, qs_get_root(&doc), 0);
+  dst = s_chtml10_node_exchange(&chtml10, qs_get_root(&doc), 0);
   qs_all_free(&doc,QX_LOGMARK);
 
   if (dst == NULL) 
@@ -148,10 +148,10 @@ chxj_exchange_chtml10(
  * @param spec  [i]   The pointer to the device_table
  */
 static void
-chxj_init_chtml10(Chtml10* chtml10, Doc* doc, request_rec* r, device_table* spec)
+s_init_chtml10(chtml10_t* chtml10, Doc* doc, request_rec* r, device_table_t* spec)
 {
   memset(doc,   0, sizeof(Doc));
-  memset(chtml10, 0, sizeof(Chtml10));
+  memset(chtml10, 0, sizeof(chtml10_t));
 
   doc->r      = r;
   chtml10->doc  = doc;
@@ -171,7 +171,7 @@ chxj_init_chtml10(Chtml10* chtml10, Doc* doc, request_rec* r, device_table* spec
  * @return The character string after it converts it is returned. 
  */
 static char*
-chtml10_node_exchange(Chtml10* chtml10, Node* node, int indent) 
+s_chtml10_node_exchange(chtml10_t* chtml10, Node* node, int indent) 
 {
   Node*         child;
   Doc*          doc   = chtml10->doc;
@@ -191,9 +191,9 @@ chtml10_node_exchange(Chtml10* chtml10, Node* node, int indent)
     /*------------------------------------------------------------------------*/
     if (strcasecmp(name, "html") == 0) 
     {
-      chtml10_start_html_tag(chtml10, child);
-      chtml10_node_exchange (chtml10, child,indent+1);
-      chtml10_end_html_tag  (chtml10, child);
+      s_chtml10_start_html_tag(chtml10, child);
+      s_chtml10_node_exchange (chtml10, child,indent+1);
+      s_chtml10_end_html_tag  (chtml10, child);
     }
     /*------------------------------------------------------------------------*/
     /* <META>                                                                 */
@@ -201,8 +201,8 @@ chtml10_node_exchange(Chtml10* chtml10, Node* node, int indent)
     else
     if (strcasecmp(name, "meta") == 0) 
     {
-      chtml10_start_meta_tag(chtml10, child);
-      chtml10_end_meta_tag  (chtml10, child);
+      s_chtml10_start_meta_tag(chtml10, child);
+      s_chtml10_end_meta_tag  (chtml10, child);
     }
     /*------------------------------------------------------------------------*/
     /* <HEAD>                                                                 */
@@ -210,9 +210,9 @@ chtml10_node_exchange(Chtml10* chtml10, Node* node, int indent)
     else
     if (strcasecmp(name, "head") == 0) 
     {
-      chtml10_start_head_tag(chtml10, child);
-      chtml10_node_exchange (chtml10, child,indent+1);
-      chtml10_end_head_tag  (chtml10, child);
+      s_chtml10_start_head_tag(chtml10, child);
+      s_chtml10_node_exchange (chtml10, child,indent+1);
+      s_chtml10_end_head_tag  (chtml10, child);
     }
     /*------------------------------------------------------------------------*/
     /* <TITLE>                                                                */
@@ -220,9 +220,9 @@ chtml10_node_exchange(Chtml10* chtml10, Node* node, int indent)
     else
     if (strcasecmp(name, "title") == 0) 
     {
-      chtml10_start_title_tag (chtml10, child);
-      chtml10_node_exchange   (chtml10, child,indent+1);
-      chtml10_end_title_tag   (chtml10, child);
+      s_chtml10_start_title_tag (chtml10, child);
+      s_chtml10_node_exchange   (chtml10, child,indent+1);
+      s_chtml10_end_title_tag   (chtml10, child);
     }
     /*------------------------------------------------------------------------*/
     /* <BASE>                                                                 */
@@ -230,8 +230,8 @@ chtml10_node_exchange(Chtml10* chtml10, Node* node, int indent)
     else
     if (strcasecmp(name, "base") == 0) 
     {
-      chtml10_start_base_tag(chtml10, child);
-      chtml10_end_base_tag  (chtml10, child);
+      s_chtml10_start_base_tag(chtml10, child);
+      s_chtml10_end_base_tag  (chtml10, child);
     }
     /*------------------------------------------------------------------------*/
     /* <BODY>                                                                 */
@@ -239,9 +239,9 @@ chtml10_node_exchange(Chtml10* chtml10, Node* node, int indent)
     else
     if (strcasecmp(name, "body") == 0) 
     {
-      chtml10_start_body_tag(chtml10, child);
-      chtml10_node_exchange (chtml10, child,indent+1);
-      chtml10_end_body_tag  (chtml10, child);
+      s_chtml10_start_body_tag(chtml10, child);
+      s_chtml10_node_exchange (chtml10, child,indent+1);
+      s_chtml10_end_body_tag  (chtml10, child);
     }
     /*------------------------------------------------------------------------*/
     /* <A>                                                                    */
@@ -249,9 +249,9 @@ chtml10_node_exchange(Chtml10* chtml10, Node* node, int indent)
     else
     if (strcasecmp(name, "a") == 0) 
     {
-      chtml10_start_a_tag   (chtml10, child);
-      chtml10_node_exchange (chtml10, child,indent+1);
-      chtml10_end_a_tag     (chtml10, child);
+      s_chtml10_start_a_tag   (chtml10, child);
+      s_chtml10_node_exchange (chtml10, child,indent+1);
+      s_chtml10_end_a_tag     (chtml10, child);
     }
     /*------------------------------------------------------------------------*/
     /* <BR>                                                                   */
@@ -259,9 +259,9 @@ chtml10_node_exchange(Chtml10* chtml10, Node* node, int indent)
     else
     if (strcasecmp(name, "br") == 0) 
     {
-      chtml10_start_br_tag  (chtml10, child);
-      chtml10_node_exchange (chtml10, child,indent+1);
-      chtml10_end_br_tag    (chtml10, child);
+      s_chtml10_start_br_tag  (chtml10, child);
+      s_chtml10_node_exchange (chtml10, child,indent+1);
+      s_chtml10_end_br_tag    (chtml10, child);
     }
     /*------------------------------------------------------------------------*/
     /* <FONT>                                                                 */
@@ -269,9 +269,9 @@ chtml10_node_exchange(Chtml10* chtml10, Node* node, int indent)
     else
     if (strcasecmp(name, "font") == 0) 
     {
-      chtml10_start_font_tag(chtml10, child);
-      chtml10_node_exchange (chtml10, child,indent+1);
-      chtml10_end_font_tag  (chtml10, child);
+      s_chtml10_start_font_tag(chtml10, child);
+      s_chtml10_node_exchange (chtml10, child,indent+1);
+      s_chtml10_end_font_tag  (chtml10, child);
     }
     /*------------------------------------------------------------------------*/
     /* <FORM>                                                                 */
@@ -279,9 +279,9 @@ chtml10_node_exchange(Chtml10* chtml10, Node* node, int indent)
     else
     if (strcasecmp(name, "form") == 0) 
     {
-      chtml10_start_form_tag(chtml10, child);
-      chtml10_node_exchange (chtml10, child,indent+1);
-      chtml10_end_form_tag  (chtml10, child);
+      s_chtml10_start_form_tag(chtml10, child);
+      s_chtml10_node_exchange (chtml10, child,indent+1);
+      s_chtml10_end_form_tag  (chtml10, child);
     }
     /*------------------------------------------------------------------------*/
     /* <INPUT>                                                                */
@@ -289,9 +289,9 @@ chtml10_node_exchange(Chtml10* chtml10, Node* node, int indent)
     else
     if (strcasecmp(name, "input") == 0) 
     {
-      chtml10_start_input_tag (chtml10, child);
-      chtml10_node_exchange   (chtml10, child,indent+1);
-      chtml10_end_input_tag   (chtml10, child);
+      s_chtml10_start_input_tag (chtml10, child);
+      s_chtml10_node_exchange   (chtml10, child,indent+1);
+      s_chtml10_end_input_tag   (chtml10, child);
     }
     /*------------------------------------------------------------------------*/
     /* <HR>                                                                   */
@@ -299,8 +299,8 @@ chtml10_node_exchange(Chtml10* chtml10, Node* node, int indent)
     else
     if (strcasecmp(name, "hr") == 0) 
     {
-      chtml10_start_hr_tag  (chtml10, child);
-      chtml10_end_hr_tag    (chtml10, child);
+      s_chtml10_start_hr_tag  (chtml10, child);
+      s_chtml10_end_hr_tag    (chtml10, child);
     }
     /*------------------------------------------------------------------------*/
     /* <CENTER>                                                               */
@@ -308,9 +308,9 @@ chtml10_node_exchange(Chtml10* chtml10, Node* node, int indent)
     else
     if (strcasecmp(name, "center") == 0) 
     {
-      chtml10_start_center_tag(chtml10, child);
-      chtml10_node_exchange   (chtml10, child,indent+1);
-      chtml10_end_center_tag  (chtml10, child);
+      s_chtml10_start_center_tag(chtml10, child);
+      s_chtml10_node_exchange   (chtml10, child,indent+1);
+      s_chtml10_end_center_tag  (chtml10, child);
     }
     /*------------------------------------------------------------------------*/
     /* <IMG>                                                                  */
@@ -318,8 +318,8 @@ chtml10_node_exchange(Chtml10* chtml10, Node* node, int indent)
     else
     if (strcasecmp(name, "img") == 0) 
     {
-      chtml10_start_img_tag (chtml10, child);
-      chtml10_end_img_tag   (chtml10, child);
+      s_chtml10_start_img_tag (chtml10, child);
+      s_chtml10_end_img_tag   (chtml10, child);
     }
     /*------------------------------------------------------------------------*/
     /* <SELECT>                                                               */
@@ -327,9 +327,9 @@ chtml10_node_exchange(Chtml10* chtml10, Node* node, int indent)
     else
     if (strcasecmp(name, "select") == 0)
     {
-      chtml10_start_select_tag(chtml10, child);
-      chtml10_node_exchange   (chtml10, child, indent+1);
-      chtml10_end_select_tag  (chtml10, child);
+      s_chtml10_start_select_tag(chtml10, child);
+      s_chtml10_node_exchange   (chtml10, child, indent+1);
+      s_chtml10_end_select_tag  (chtml10, child);
     }
     /*------------------------------------------------------------------------*/
     /* <OPTION>                                                               */
@@ -337,9 +337,9 @@ chtml10_node_exchange(Chtml10* chtml10, Node* node, int indent)
     else
     if (strcasecmp(name, "option") == 0)
     {
-      chtml10_start_option_tag(chtml10, child);
-      chtml10_node_exchange   (chtml10, child, indent+1);
-      chtml10_end_option_tag  (chtml10, child);
+      s_chtml10_start_option_tag(chtml10, child);
+      s_chtml10_node_exchange   (chtml10, child, indent+1);
+      s_chtml10_end_option_tag  (chtml10, child);
     }
     /*------------------------------------------------------------------------*/
     /* <DIV>                                                                  */
@@ -347,9 +347,9 @@ chtml10_node_exchange(Chtml10* chtml10, Node* node, int indent)
     else
     if (strcasecmp(name, "div") == 0)
     {
-      chtml10_start_div_tag (chtml10, child);
-      chtml10_node_exchange (chtml10, child, indent+1);
-      chtml10_end_div_tag   (chtml10, child);
+      s_chtml10_start_div_tag (chtml10, child);
+      s_chtml10_node_exchange (chtml10, child, indent+1);
+      s_chtml10_end_div_tag   (chtml10, child);
     }
     /*------------------------------------------------------------------------*/
     /* <CHXJ:IF>                                                              */
@@ -365,11 +365,11 @@ chtml10_node_exchange(Chtml10* chtml10, Node* node, int indent)
         parse_attr = qs_get_parse_attr(doc, child, r);
         if (parse_attr != NULL && strcasecmp(parse_attr, "true") == 0)
         {
-          chtml10_node_exchange (chtml10, child, indent+1);
+          s_chtml10_node_exchange (chtml10, child, indent+1);
         }
         else
         {
-          chtml10_chxjif_tag(chtml10, child);
+          s_chtml10_chxjif_tag(chtml10, child);
         }
       }
     }
@@ -403,7 +403,7 @@ chtml10_node_exchange(Chtml10* chtml10, Node* node, int indent)
       for (ii=0; ii<qs_get_node_size(doc,child); ii++)
       {
         char* out;
-        int rtn = chtml10_search_emoji(chtml10, &textval[ii], &out);
+        int rtn = s_chtml10_search_emoji(chtml10, &textval[ii], &out);
         if (rtn != 0)
         {
           tdst = qs_out_apr_pstrcat(r, tdst, out, &tdst_len);
@@ -442,11 +442,11 @@ chtml10_node_exchange(Chtml10* chtml10, Node* node, int indent)
  * @return When corresponding EMOJI exists, it returns it excluding 0. 
  */
 static int
-chtml10_search_emoji(Chtml10* chtml10, char* txt, char** rslt)
+s_chtml10_search_emoji(chtml10_t* chtml10, char* txt, char** rslt)
 {
   emoji_t*      ee;
   request_rec*  r;
-  device_table* spec;
+  device_table_t* spec;
   int           len;
 
   spec = chtml10->spec;
@@ -498,7 +498,7 @@ chtml10_search_emoji(Chtml10* chtml10, char* txt, char** rslt)
  * @return The conversion result is returned.
  */
 static char*
-chtml10_start_html_tag(Chtml10* chtml10, Node* node) 
+s_chtml10_start_html_tag(chtml10_t* chtml10, Node* node) 
 {
   Doc*          doc   = chtml10->doc;
   request_rec*  r     = doc->r;
@@ -520,7 +520,7 @@ chtml10_start_html_tag(Chtml10* chtml10, Node* node)
  * @return The conversion result is returned.
  */
 static char*
-chtml10_end_html_tag(Chtml10* chtml10, Node* child) 
+s_chtml10_end_html_tag(chtml10_t* chtml10, Node* child) 
 {
   Doc*          doc = chtml10->doc;
   request_rec*  r   = doc->r;
@@ -539,7 +539,7 @@ chtml10_end_html_tag(Chtml10* chtml10, Node* child)
  * @return The conversion result is returned.
  */
 static char*
-chtml10_start_meta_tag(Chtml10* chtml10, Node* node) 
+s_chtml10_start_meta_tag(chtml10_t* chtml10, Node* node) 
 {
   /* ignore */
   return chtml10->out;
@@ -554,7 +554,7 @@ chtml10_start_meta_tag(Chtml10* chtml10, Node* node)
  * @return The conversion result is returned.
  */
 static char*
-chtml10_end_meta_tag(Chtml10* chtml10, Node* child) 
+s_chtml10_end_meta_tag(chtml10_t* chtml10, Node* child) 
 {
   return chtml10->out;
 }
@@ -568,7 +568,7 @@ chtml10_end_meta_tag(Chtml10* chtml10, Node* child)
  * @return The conversion result is returned.
  */
 static char*
-chtml10_start_head_tag(Chtml10* chtml10, Node* node) 
+s_chtml10_start_head_tag(chtml10_t* chtml10, Node* node) 
 {
   Doc*          doc = chtml10->doc;
   request_rec*  r   = doc->r;
@@ -586,7 +586,7 @@ chtml10_start_head_tag(Chtml10* chtml10, Node* node)
  * @return The conversion result is returned.
  */
 static char*
-chtml10_end_head_tag(Chtml10* chtml10, Node* child) 
+s_chtml10_end_head_tag(chtml10_t* chtml10, Node* child) 
 {
   Doc*          doc = chtml10->doc;
   request_rec*  r   = doc->r;
@@ -604,7 +604,7 @@ chtml10_end_head_tag(Chtml10* chtml10, Node* child)
  * @return The conversion result is returned.
  */
 static char*
-chtml10_start_title_tag(Chtml10* chtml10, Node* node) 
+s_chtml10_start_title_tag(chtml10_t* chtml10, Node* node) 
 {
   Doc* doc = chtml10->doc;
   request_rec* r = doc->r;
@@ -622,7 +622,7 @@ chtml10_start_title_tag(Chtml10* chtml10, Node* node)
  * @return The conversion result is returned.
  */
 static char*
-chtml10_end_title_tag(Chtml10* chtml10, Node* child) 
+s_chtml10_end_title_tag(chtml10_t* chtml10, Node* child) 
 {
   Doc*          doc = chtml10->doc;
   request_rec*  r   = doc->r;
@@ -641,7 +641,7 @@ chtml10_end_title_tag(Chtml10* chtml10, Node* child)
  * @return The conversion result is returned.
  */
 static char*
-chtml10_start_base_tag(Chtml10* chtml10, Node* node) 
+s_chtml10_start_base_tag(chtml10_t* chtml10, Node* node) 
 {
   Attr*         attr;
   Doc*          doc   = chtml10->doc;
@@ -681,7 +681,7 @@ chtml10_start_base_tag(Chtml10* chtml10, Node* node)
  * @return The conversion result is returned.
  */
 static char*
-chtml10_end_base_tag(Chtml10* chtml10, Node* child) 
+s_chtml10_end_base_tag(chtml10_t* chtml10, Node* child) 
 {
   return chtml10->out;
 }
@@ -695,7 +695,7 @@ chtml10_end_base_tag(Chtml10* chtml10, Node* child)
  * @return The conversion result is returned.
  */
 static char*
-chtml10_start_body_tag(Chtml10* chtml10, Node* node) 
+s_chtml10_start_body_tag(chtml10_t* chtml10, Node* node) 
 {
   Doc* doc = chtml10->doc;
   request_rec* r = doc->r;
@@ -766,7 +766,7 @@ chtml10_start_body_tag(Chtml10* chtml10, Node* node)
  * @return The conversion result is returned.
  */
 static char*
-chtml10_end_body_tag(Chtml10* chtml10, Node* child) 
+s_chtml10_end_body_tag(chtml10_t* chtml10, Node* child) 
 {
   Doc*          doc = chtml10->doc;
   request_rec*  r = doc->r;
@@ -785,7 +785,7 @@ chtml10_end_body_tag(Chtml10* chtml10, Node* child)
  * @return The conversion result is returned.
  */
 static char*
-chtml10_start_a_tag(Chtml10* chtml10, Node* node) 
+s_chtml10_start_a_tag(chtml10_t* chtml10, Node* node) 
 {
   Doc*          doc   = chtml10->doc;
   request_rec*  r     = doc->r;
@@ -935,7 +935,7 @@ chtml10_start_a_tag(Chtml10* chtml10, Node* node)
  * @return The conversion result is returned.
  */
 static char*
-chtml10_end_a_tag(Chtml10* chtml10, Node* child) 
+s_chtml10_end_a_tag(chtml10_t* chtml10, Node* child) 
 {
   Doc* doc = chtml10->doc;
   request_rec* r = doc->r;
@@ -953,7 +953,7 @@ chtml10_end_a_tag(Chtml10* chtml10, Node* child)
  * @return The conversion result is returned.
  */
 static char*
-chtml10_start_br_tag(Chtml10* chtml10, Node* node) 
+s_chtml10_start_br_tag(chtml10_t* chtml10, Node* node) 
 {
   Doc* doc = chtml10->doc;
   request_rec* r = doc->r;
@@ -970,7 +970,7 @@ chtml10_start_br_tag(Chtml10* chtml10, Node* node)
  * @return The conversion result is returned.
  */
 static char*
-chtml10_end_br_tag(Chtml10* chtml10, Node* child) 
+s_chtml10_end_br_tag(chtml10_t* chtml10, Node* child) 
 {
   return chtml10->out;
 }
@@ -984,7 +984,7 @@ chtml10_end_br_tag(Chtml10* chtml10, Node* child)
  * @return The conversion result is returned.
  */
 static char*
-chtml10_start_font_tag(Chtml10* chtml10, Node* node) 
+s_chtml10_start_font_tag(chtml10_t* chtml10, Node* node) 
 {
   /* Ignore */
 
@@ -1000,7 +1000,7 @@ chtml10_start_font_tag(Chtml10* chtml10, Node* node)
  * @return The conversion result is returned.
  */
 static char*
-chtml10_end_font_tag(Chtml10* chtml10, Node* child) 
+s_chtml10_end_font_tag(chtml10_t* chtml10, Node* child) 
 {
   /* ignore */
   return chtml10->out;
@@ -1015,7 +1015,7 @@ chtml10_end_font_tag(Chtml10* chtml10, Node* child)
  * @return The conversion result is returned.
  */
 static char*
-chtml10_start_form_tag(Chtml10* chtml10, Node* node) 
+s_chtml10_start_form_tag(chtml10_t* chtml10, Node* node) 
 {
   Doc* doc = chtml10->doc;
   request_rec* r = doc->r;
@@ -1079,7 +1079,7 @@ chtml10_start_form_tag(Chtml10* chtml10, Node* node)
  * @return The conversion result is returned.
  */
 static char*
-chtml10_end_form_tag(Chtml10* chtml10, Node* child) 
+s_chtml10_end_form_tag(chtml10_t* chtml10, Node* child) 
 {
   Doc* doc = chtml10->doc;
   request_rec* r = doc->r;
@@ -1097,7 +1097,7 @@ chtml10_end_form_tag(Chtml10* chtml10, Node* child)
  * @return The conversion result is returned.
  */
 static char*
-chtml10_start_input_tag(Chtml10* chtml10, Node* node) 
+s_chtml10_start_input_tag(chtml10_t* chtml10, Node* node) 
 {
   Doc*          doc         = chtml10->doc;
   request_rec*  r           = doc->r;
@@ -1208,7 +1208,7 @@ chtml10_start_input_tag(Chtml10* chtml10, Node* node)
  * @return The conversion result is returned.
  */
 static char*
-chtml10_end_input_tag(Chtml10* chtml10, Node* child) 
+s_chtml10_end_input_tag(chtml10_t* chtml10, Node* child) 
 {
   return chtml10->out;
 }
@@ -1222,7 +1222,7 @@ chtml10_end_input_tag(Chtml10* chtml10, Node* child)
  * @return The conversion result is returned.
  */
 static char*
-chtml10_start_center_tag(Chtml10* chtml10, Node* node) 
+s_chtml10_start_center_tag(chtml10_t* chtml10, Node* node) 
 {
   Doc*          doc = chtml10->doc;
   request_rec*  r   = doc->r;
@@ -1241,7 +1241,7 @@ chtml10_start_center_tag(Chtml10* chtml10, Node* node)
  * @return The conversion result is returned.
  */
 static char*
-chtml10_end_center_tag(Chtml10* chtml10, Node* child) 
+s_chtml10_end_center_tag(chtml10_t* chtml10, Node* child) 
 {
   Doc*          doc = chtml10->doc;
   request_rec*  r   = doc->r;
@@ -1260,7 +1260,7 @@ chtml10_end_center_tag(Chtml10* chtml10, Node* child)
  * @return The conversion result is returned.
  */
 static char*
-chtml10_start_hr_tag(Chtml10* chtml10, Node* node) 
+s_chtml10_start_hr_tag(chtml10_t* chtml10, Node* node) 
 {
   Doc* doc = chtml10->doc;
   request_rec* r = doc->r;
@@ -1336,7 +1336,7 @@ chtml10_start_hr_tag(Chtml10* chtml10, Node* node)
  * @return The conversion result is returned.
  */
 static char*
-chtml10_end_hr_tag(Chtml10* chtml10, Node* child) 
+s_chtml10_end_hr_tag(chtml10_t* chtml10, Node* child) 
 {
   return chtml10->out;
 }
@@ -1350,13 +1350,13 @@ chtml10_end_hr_tag(Chtml10* chtml10, Node* child)
  * @return The conversion result is returned.
  */
 static char*
-chtml10_start_img_tag(Chtml10* chtml10, Node* node) 
+s_chtml10_start_img_tag(chtml10_t* chtml10, Node* node) 
 {
   Doc*          doc = chtml10->doc;
   request_rec*  r   = doc->r;
   Attr* attr;
 #ifndef IMG_NOT_CONVERT_FILENAME
-  device_table* spec = chtml10->spec;
+  device_table_t* spec = chtml10->spec;
 #endif
 
   chtml10->out = apr_pstrcat(r->pool, chtml10->out, "<img", NULL);
@@ -1465,7 +1465,7 @@ chtml10_start_img_tag(Chtml10* chtml10, Node* node)
  * @return The conversion result is returned.
  */
 static char*
-chtml10_end_img_tag(Chtml10* chtml10, Node* child) 
+s_chtml10_end_img_tag(chtml10_t* chtml10, Node* child) 
 {
   return chtml10->out;
 }
@@ -1479,7 +1479,7 @@ chtml10_end_img_tag(Chtml10* chtml10, Node* child)
  * @return The conversion result is returned.
  */
 static char*
-chtml10_start_select_tag(Chtml10* chtml10, Node* child)
+s_chtml10_start_select_tag(chtml10_t* chtml10, Node* child)
 {
   Doc* doc = chtml10->doc;
   request_rec* r = doc->r;
@@ -1542,7 +1542,7 @@ chtml10_start_select_tag(Chtml10* chtml10, Node* child)
  * @return The conversion result is returned.
  */
 static char*
-chtml10_end_select_tag(Chtml10* chtml10, Node* child)
+s_chtml10_end_select_tag(chtml10_t* chtml10, Node* child)
 {
   Doc* doc = chtml10->doc;
   request_rec* r = doc->r;
@@ -1560,7 +1560,7 @@ chtml10_end_select_tag(Chtml10* chtml10, Node* child)
  * @return The conversion result is returned.
  */
 static char*
-chtml10_start_option_tag(Chtml10* chtml10, Node* child)
+s_chtml10_start_option_tag(chtml10_t* chtml10, Node* child)
 {
   Doc* doc = chtml10->doc;
   request_rec* r = doc->r;
@@ -1621,7 +1621,7 @@ chtml10_start_option_tag(Chtml10* chtml10, Node* child)
  * @return The conversion result is returned.
  */
 static char*
-chtml10_end_option_tag(Chtml10* chtml10, Node* child)
+s_chtml10_end_option_tag(chtml10_t* chtml10, Node* child)
 {
   /* Don't close */
   return chtml10->out;
@@ -1636,7 +1636,7 @@ chtml10_end_option_tag(Chtml10* chtml10, Node* child)
  * @return The conversion result is returned.
  */
 static char*
-chtml10_start_div_tag(Chtml10* chtml10, Node* child)
+s_chtml10_start_div_tag(chtml10_t* chtml10, Node* child)
 {
   Doc* doc = chtml10->doc;
   request_rec* r = doc->r;
@@ -1680,7 +1680,7 @@ chtml10_start_div_tag(Chtml10* chtml10, Node* child)
  * @return The conversion result is returned.
  */
 static char*
-chtml10_end_div_tag(Chtml10* chtml10, Node* child)
+s_chtml10_end_div_tag(chtml10_t* chtml10, Node* child)
 {
   Doc* doc = chtml10->doc;
   request_rec* r = doc->r;
@@ -1691,7 +1691,7 @@ chtml10_end_div_tag(Chtml10* chtml10, Node* child)
 }
 
 static void
-chtml10_chxjif_tag(Chtml10* chtml10, Node* node)
+s_chtml10_chxjif_tag(chtml10_t* chtml10, Node* node)
 {
   Doc*         doc   = chtml10->doc;
   Node*        child;
@@ -1702,7 +1702,7 @@ chtml10_chxjif_tag(Chtml10* chtml10, Node* node)
        child = qs_get_next_node(doc, child))
   {
     chtml10->out = apr_pstrcat(r->pool, chtml10->out, child->otext, NULL);
-    chtml10_chxjif_tag(chtml10, child);
+    s_chtml10_chxjif_tag(chtml10, child);
   }
 }
 /*
