@@ -21,44 +21,44 @@
 #include "chxj_img_conv.h"
 #include "chxj_qr_code.h"
 
-static char* chtml20_node_exchange    (Chtml20* chtml, Node* node, int indent);
-static char* chtml20_start_html_tag   (Chtml20* chtml, Node* child);
-static char* chtml20_end_html_tag     (Chtml20* chtml, Node* child);
-static char* chtml20_start_meta_tag   (Chtml20* chtml, Node* node);
-static char* chtml20_end_meta_tag     (Chtml20* chtml, Node* node);
-static char* chtml20_start_head_tag   (Chtml20* chtml, Node* node);
-static char* chtml20_end_head_tag     (Chtml20* chtml, Node* node);
-static char* chtml20_start_title_tag  (Chtml20* chtml, Node* node);
-static char* chtml20_end_title_tag    (Chtml20* chtml, Node* node);
-static char* chtml20_start_base_tag   (Chtml20* chtml, Node* node);
-static char* chtml20_end_base_tag     (Chtml20* chtml, Node* node);
-static char* chtml20_start_body_tag   (Chtml20* chtml, Node* node);
-static char* chtml20_end_body_tag     (Chtml20* chtml, Node* node);
-static char* chtml20_start_a_tag      (Chtml20* chtml, Node* node);
-static char* chtml20_end_a_tag        (Chtml20* chtml, Node* node);
-static char* chtml20_start_br_tag     (Chtml20* chtml, Node* node);
-static char* chtml20_end_br_tag       (Chtml20* chtml, Node* node);
-static char* chtml20_start_font_tag   (Chtml20* chtml, Node* node);
-static char* chtml20_end_font_tag     (Chtml20* chtml, Node* node);
-static char* chtml20_start_form_tag   (Chtml20* chtml, Node* node);
-static char* chtml20_end_form_tag     (Chtml20* chtml, Node* node);
-static char* chtml20_start_input_tag  (Chtml20* chtml, Node* node);
-static char* chtml20_end_input_tag    (Chtml20* chtml, Node* node);
-static char* chtml20_start_center_tag (Chtml20* chtml, Node* node);
-static char* chtml20_end_center_tag   (Chtml20* chtml, Node* node);
-static char* chtml20_start_hr_tag     (Chtml20* chtml, Node* node);
-static char* chtml20_end_hr_tag       (Chtml20* chtml, Node* node);
-static char* chtml20_start_img_tag    (Chtml20* chtml, Node* node);
-static char* chtml20_end_img_tag      (Chtml20* chtml, Node* node);
-static char* chtml20_start_select_tag (Chtml20* chtml, Node* node);
-static char* chtml20_end_select_tag   (Chtml20* chtml, Node* node);
-static char* chtml20_start_option_tag (Chtml20* chtml, Node* node);
-static char* chtml20_end_option_tag   (Chtml20* chtml, Node* node);
-static char* chtml20_start_div_tag    (Chtml20* chtml, Node* node);
-static char* chtml20_end_div_tag      (Chtml20* chtml, Node* node);
-static void chxj_init_chtml20(Chtml20* chtml, Doc* doc, request_rec* r, device_table* spec);
-static int chtml20_search_emoji(Chtml20* chtml, char* txt, char** rslt);
-static void chtml20_chxjif_tag(Chtml20* chtml, Node* node); 
+static char* s_chtml20_node_exchange    (chtml20_t* chtml, Node* node, int indent);
+static char* s_chtml20_start_html_tag   (chtml20_t* chtml, Node* child);
+static char* s_chtml20_end_html_tag     (chtml20_t* chtml, Node* child);
+static char* s_chtml20_start_meta_tag   (chtml20_t* chtml, Node* node);
+static char* s_chtml20_end_meta_tag     (chtml20_t* chtml, Node* node);
+static char* s_chtml20_start_head_tag   (chtml20_t* chtml, Node* node);
+static char* s_chtml20_end_head_tag     (chtml20_t* chtml, Node* node);
+static char* s_chtml20_start_title_tag  (chtml20_t* chtml, Node* node);
+static char* s_chtml20_end_title_tag    (chtml20_t* chtml, Node* node);
+static char* s_chtml20_start_base_tag   (chtml20_t* chtml, Node* node);
+static char* s_chtml20_end_base_tag     (chtml20_t* chtml, Node* node);
+static char* s_chtml20_start_body_tag   (chtml20_t* chtml, Node* node);
+static char* s_chtml20_end_body_tag     (chtml20_t* chtml, Node* node);
+static char* s_chtml20_start_a_tag      (chtml20_t* chtml, Node* node);
+static char* s_chtml20_end_a_tag        (chtml20_t* chtml, Node* node);
+static char* s_chtml20_start_br_tag     (chtml20_t* chtml, Node* node);
+static char* s_chtml20_end_br_tag       (chtml20_t* chtml, Node* node);
+static char* s_chtml20_start_font_tag   (chtml20_t* chtml, Node* node);
+static char* s_chtml20_end_font_tag     (chtml20_t* chtml, Node* node);
+static char* s_chtml20_start_form_tag   (chtml20_t* chtml, Node* node);
+static char* s_chtml20_end_form_tag     (chtml20_t* chtml, Node* node);
+static char* s_chtml20_start_input_tag  (chtml20_t* chtml, Node* node);
+static char* s_chtml20_end_input_tag    (chtml20_t* chtml, Node* node);
+static char* s_chtml20_start_center_tag (chtml20_t* chtml, Node* node);
+static char* s_chtml20_end_center_tag   (chtml20_t* chtml, Node* node);
+static char* s_chtml20_start_hr_tag     (chtml20_t* chtml, Node* node);
+static char* s_chtml20_end_hr_tag       (chtml20_t* chtml, Node* node);
+static char* s_chtml20_start_img_tag    (chtml20_t* chtml, Node* node);
+static char* s_chtml20_end_img_tag      (chtml20_t* chtml, Node* node);
+static char* s_chtml20_start_select_tag (chtml20_t* chtml, Node* node);
+static char* s_chtml20_end_select_tag   (chtml20_t* chtml, Node* node);
+static char* s_chtml20_start_option_tag (chtml20_t* chtml, Node* node);
+static char* s_chtml20_end_option_tag   (chtml20_t* chtml, Node* node);
+static char* s_chtml20_start_div_tag    (chtml20_t* chtml, Node* node);
+static char* s_chtml20_end_div_tag      (chtml20_t* chtml, Node* node);
+static void  s_init_chtml20(chtml20_t* chtml, Doc* doc, request_rec* r, device_table_t* spec);
+static int   s_chtml20_search_emoji(chtml20_t* chtml, char* txt, char** rslt);
+static void  s_chtml20_chxjif_tag(chtml20_t* chtml, Node* node); 
 
 /**
  * converts from CHTML5.0 to CHTML2.0.
@@ -72,14 +72,14 @@ static void chtml20_chxjif_tag(Chtml20* chtml, Node* node);
 char*
 chxj_exchange_chtml20(
   request_rec* r,
-  device_table *spec,
+  device_table_t* spec,
   const char* src,
   apr_size_t srclen,
   apr_size_t *dstlen)
 {
   char*     dst = NULL;
   char*     ss;
-  Chtml20   chtml20;
+  chtml20_t   chtml20;
   Doc       doc;
 
   /*--------------------------------------------------------------------------*/
@@ -97,7 +97,7 @@ chxj_exchange_chtml20(
   /*--------------------------------------------------------------------------*/
   /* The CHTML structure is initialized.                                      */
   /*--------------------------------------------------------------------------*/
-  chxj_init_chtml20(&chtml20, &doc, r, spec);
+  s_init_chtml20(&chtml20, &doc, r, spec);
   ap_set_content_type(r, "text/html; charset=Windows-31J");
 
   /*--------------------------------------------------------------------------*/
@@ -118,7 +118,7 @@ chxj_exchange_chtml20(
   /*--------------------------------------------------------------------------*/
   /* It converts it from CHTML to CHTML.                                      */
   /*--------------------------------------------------------------------------*/
-  dst = chtml20_node_exchange(&chtml20, qs_get_root(&doc), 0);
+  dst = s_chtml20_node_exchange(&chtml20, qs_get_root(&doc), 0);
   qs_all_free(&doc,QX_LOGMARK);
 
   if (dst == NULL) 
@@ -148,10 +148,10 @@ chxj_exchange_chtml20(
  * @param spec  [i]   The pointer to the device_table
  */
 static void
-chxj_init_chtml20(Chtml20* chtml20, Doc* doc, request_rec* r, device_table* spec)
+s_init_chtml20(chtml20_t* chtml20, Doc* doc, request_rec* r, device_table_t* spec)
 {
   memset(doc,   0, sizeof(Doc));
-  memset(chtml20, 0, sizeof(Chtml20));
+  memset(chtml20, 0, sizeof(chtml20_t));
 
   doc->r      = r;
   chtml20->doc  = doc;
@@ -171,7 +171,7 @@ chxj_init_chtml20(Chtml20* chtml20, Doc* doc, request_rec* r, device_table* spec
  * @return The character string after it converts it is returned. 
  */
 static char*
-chtml20_node_exchange(Chtml20* chtml20, Node* node, int indent) 
+s_chtml20_node_exchange(chtml20_t* chtml20, Node* node, int indent) 
 {
   Node*         child;
   Doc*          doc   = chtml20->doc;
@@ -191,9 +191,9 @@ chtml20_node_exchange(Chtml20* chtml20, Node* node, int indent)
     /*------------------------------------------------------------------------*/
     if (strcasecmp(name, "html") == 0) 
     {
-      chtml20_start_html_tag(chtml20, child);
-      chtml20_node_exchange (chtml20, child,indent+1);
-      chtml20_end_html_tag  (chtml20, child);
+      s_chtml20_start_html_tag(chtml20, child);
+      s_chtml20_node_exchange (chtml20, child,indent+1);
+      s_chtml20_end_html_tag  (chtml20, child);
     }
     /*------------------------------------------------------------------------*/
     /* <META>                                                                 */
@@ -201,8 +201,8 @@ chtml20_node_exchange(Chtml20* chtml20, Node* node, int indent)
     else
     if (strcasecmp(name, "meta") == 0) 
     {
-      chtml20_start_meta_tag(chtml20, child);
-      chtml20_end_meta_tag  (chtml20, child);
+      s_chtml20_start_meta_tag(chtml20, child);
+      s_chtml20_end_meta_tag  (chtml20, child);
     }
     /*------------------------------------------------------------------------*/
     /* <HEAD>                                                                 */
@@ -210,9 +210,9 @@ chtml20_node_exchange(Chtml20* chtml20, Node* node, int indent)
     else
     if (strcasecmp(name, "head") == 0) 
     {
-      chtml20_start_head_tag(chtml20, child);
-      chtml20_node_exchange (chtml20, child,indent+1);
-      chtml20_end_head_tag  (chtml20, child);
+      s_chtml20_start_head_tag(chtml20, child);
+      s_chtml20_node_exchange (chtml20, child,indent+1);
+      s_chtml20_end_head_tag  (chtml20, child);
     }
     /*------------------------------------------------------------------------*/
     /* <TITLE>                                                                */
@@ -220,9 +220,9 @@ chtml20_node_exchange(Chtml20* chtml20, Node* node, int indent)
     else
     if (strcasecmp(name, "title") == 0) 
     {
-      chtml20_start_title_tag (chtml20, child);
-      chtml20_node_exchange   (chtml20, child,indent+1);
-      chtml20_end_title_tag   (chtml20, child);
+      s_chtml20_start_title_tag (chtml20, child);
+      s_chtml20_node_exchange   (chtml20, child,indent+1);
+      s_chtml20_end_title_tag   (chtml20, child);
     }
     /*------------------------------------------------------------------------*/
     /* <BASE>                                                                 */
@@ -230,8 +230,8 @@ chtml20_node_exchange(Chtml20* chtml20, Node* node, int indent)
     else
     if (strcasecmp(name, "base") == 0) 
     {
-      chtml20_start_base_tag(chtml20, child);
-      chtml20_end_base_tag  (chtml20, child);
+      s_chtml20_start_base_tag(chtml20, child);
+      s_chtml20_end_base_tag  (chtml20, child);
     }
     /*------------------------------------------------------------------------*/
     /* <BODY>                                                                 */
@@ -239,9 +239,9 @@ chtml20_node_exchange(Chtml20* chtml20, Node* node, int indent)
     else
     if (strcasecmp(name, "body") == 0) 
     {
-      chtml20_start_body_tag(chtml20, child);
-      chtml20_node_exchange (chtml20, child,indent+1);
-      chtml20_end_body_tag  (chtml20, child);
+      s_chtml20_start_body_tag(chtml20, child);
+      s_chtml20_node_exchange (chtml20, child,indent+1);
+      s_chtml20_end_body_tag  (chtml20, child);
     }
     /*------------------------------------------------------------------------*/
     /* <A>                                                                    */
@@ -249,9 +249,9 @@ chtml20_node_exchange(Chtml20* chtml20, Node* node, int indent)
     else
     if (strcasecmp(name, "a") == 0) 
     {
-      chtml20_start_a_tag   (chtml20, child);
-      chtml20_node_exchange (chtml20, child,indent+1);
-      chtml20_end_a_tag     (chtml20, child);
+      s_chtml20_start_a_tag   (chtml20, child);
+      s_chtml20_node_exchange (chtml20, child,indent+1);
+      s_chtml20_end_a_tag     (chtml20, child);
     }
     /*------------------------------------------------------------------------*/
     /* <BR>                                                                   */
@@ -259,9 +259,9 @@ chtml20_node_exchange(Chtml20* chtml20, Node* node, int indent)
     else
     if (strcasecmp(name, "br") == 0) 
     {
-      chtml20_start_br_tag  (chtml20, child);
-      chtml20_node_exchange (chtml20, child,indent+1);
-      chtml20_end_br_tag    (chtml20, child);
+      s_chtml20_start_br_tag  (chtml20, child);
+      s_chtml20_node_exchange (chtml20, child,indent+1);
+      s_chtml20_end_br_tag    (chtml20, child);
     }
     /*------------------------------------------------------------------------*/
     /* <FONT>                                                                 */
@@ -269,9 +269,9 @@ chtml20_node_exchange(Chtml20* chtml20, Node* node, int indent)
     else
     if (strcasecmp(name, "font") == 0) 
     {
-      chtml20_start_font_tag(chtml20, child);
-      chtml20_node_exchange (chtml20, child,indent+1);
-      chtml20_end_font_tag  (chtml20, child);
+      s_chtml20_start_font_tag(chtml20, child);
+      s_chtml20_node_exchange (chtml20, child,indent+1);
+      s_chtml20_end_font_tag  (chtml20, child);
     }
     /*------------------------------------------------------------------------*/
     /* <FORM>                                                                 */
@@ -279,9 +279,9 @@ chtml20_node_exchange(Chtml20* chtml20, Node* node, int indent)
     else
     if (strcasecmp(name, "form") == 0) 
     {
-      chtml20_start_form_tag(chtml20, child);
-      chtml20_node_exchange (chtml20, child,indent+1);
-      chtml20_end_form_tag  (chtml20, child);
+      s_chtml20_start_form_tag(chtml20, child);
+      s_chtml20_node_exchange (chtml20, child,indent+1);
+      s_chtml20_end_form_tag  (chtml20, child);
     }
     /*------------------------------------------------------------------------*/
     /* <INPUT>                                                                */
@@ -289,9 +289,9 @@ chtml20_node_exchange(Chtml20* chtml20, Node* node, int indent)
     else
     if (strcasecmp(name, "input") == 0) 
     {
-      chtml20_start_input_tag (chtml20, child);
-      chtml20_node_exchange   (chtml20, child,indent+1);
-      chtml20_end_input_tag   (chtml20, child);
+      s_chtml20_start_input_tag (chtml20, child);
+      s_chtml20_node_exchange   (chtml20, child,indent+1);
+      s_chtml20_end_input_tag   (chtml20, child);
     }
     /*------------------------------------------------------------------------*/
     /* <HR>                                                                   */
@@ -299,8 +299,8 @@ chtml20_node_exchange(Chtml20* chtml20, Node* node, int indent)
     else
     if (strcasecmp(name, "hr") == 0) 
     {
-      chtml20_start_hr_tag  (chtml20, child);
-      chtml20_end_hr_tag    (chtml20, child);
+      s_chtml20_start_hr_tag  (chtml20, child);
+      s_chtml20_end_hr_tag    (chtml20, child);
     }
     /*------------------------------------------------------------------------*/
     /* <CENTER>                                                               */
@@ -308,9 +308,9 @@ chtml20_node_exchange(Chtml20* chtml20, Node* node, int indent)
     else
     if (strcasecmp(name, "center") == 0) 
     {
-      chtml20_start_center_tag(chtml20, child);
-      chtml20_node_exchange   (chtml20, child,indent+1);
-      chtml20_end_center_tag  (chtml20, child);
+      s_chtml20_start_center_tag(chtml20, child);
+      s_chtml20_node_exchange   (chtml20, child,indent+1);
+      s_chtml20_end_center_tag  (chtml20, child);
     }
     /*------------------------------------------------------------------------*/
     /* <IMG>                                                                  */
@@ -318,8 +318,8 @@ chtml20_node_exchange(Chtml20* chtml20, Node* node, int indent)
     else
     if (strcasecmp(name, "img") == 0) 
     {
-      chtml20_start_img_tag (chtml20, child);
-      chtml20_end_img_tag   (chtml20, child);
+      s_chtml20_start_img_tag (chtml20, child);
+      s_chtml20_end_img_tag   (chtml20, child);
     }
     /*------------------------------------------------------------------------*/
     /* <SELECT>                                                               */
@@ -327,9 +327,9 @@ chtml20_node_exchange(Chtml20* chtml20, Node* node, int indent)
     else
     if (strcasecmp(name, "select") == 0)
     {
-      chtml20_start_select_tag(chtml20, child);
-      chtml20_node_exchange   (chtml20, child, indent+1);
-      chtml20_end_select_tag  (chtml20, child);
+      s_chtml20_start_select_tag(chtml20, child);
+      s_chtml20_node_exchange   (chtml20, child, indent+1);
+      s_chtml20_end_select_tag  (chtml20, child);
     }
     /*------------------------------------------------------------------------*/
     /* <OPTION>                                                               */
@@ -337,9 +337,9 @@ chtml20_node_exchange(Chtml20* chtml20, Node* node, int indent)
     else
     if (strcasecmp(name, "option") == 0)
     {
-      chtml20_start_option_tag(chtml20, child);
-      chtml20_node_exchange   (chtml20, child, indent+1);
-      chtml20_end_option_tag  (chtml20, child);
+      s_chtml20_start_option_tag(chtml20, child);
+      s_chtml20_node_exchange   (chtml20, child, indent+1);
+      s_chtml20_end_option_tag  (chtml20, child);
     }
     /*------------------------------------------------------------------------*/
     /* <DIV>                                                                  */
@@ -347,9 +347,9 @@ chtml20_node_exchange(Chtml20* chtml20, Node* node, int indent)
     else
     if (strcasecmp(name, "div") == 0)
     {
-      chtml20_start_div_tag (chtml20, child);
-      chtml20_node_exchange (chtml20, child, indent+1);
-      chtml20_end_div_tag   (chtml20, child);
+      s_chtml20_start_div_tag (chtml20, child);
+      s_chtml20_node_exchange (chtml20, child, indent+1);
+      s_chtml20_end_div_tag   (chtml20, child);
     }
     /*------------------------------------------------------------------------*/
     /* <BLINK>                                                                */
@@ -373,11 +373,11 @@ chtml20_node_exchange(Chtml20* chtml20, Node* node, int indent)
         parse_attr = qs_get_parse_attr(doc, child, r);
         if (parse_attr != NULL && strcasecmp(parse_attr, "true") == 0)
         {
-          chtml20_node_exchange (chtml20, child, indent+1);
+          s_chtml20_node_exchange (chtml20, child, indent+1);
         }
         else
         {
-          chtml20_chxjif_tag(chtml20, child);
+          s_chtml20_chxjif_tag(chtml20, child);
         }
       }
     }
@@ -411,7 +411,7 @@ chtml20_node_exchange(Chtml20* chtml20, Node* node, int indent)
       for (ii=0; ii<qs_get_node_size(doc,child); ii++)
       {
         char* out;
-        int rtn = chtml20_search_emoji(chtml20, &textval[ii], &out);
+        int rtn = s_chtml20_search_emoji(chtml20, &textval[ii], &out);
         if (rtn != 0)
         {
           tdst = qs_out_apr_pstrcat(r, tdst, out, &tdst_len);
@@ -450,11 +450,11 @@ chtml20_node_exchange(Chtml20* chtml20, Node* node, int indent)
  * @return When corresponding EMOJI exists, it returns it excluding 0. 
  */
 static int
-chtml20_search_emoji(Chtml20* chtml20, char* txt, char** rslt)
+s_chtml20_search_emoji(chtml20_t* chtml20, char* txt, char** rslt)
 {
   emoji_t*      ee;
   request_rec*  r;
-  device_table* spec;
+  device_table_t* spec;
   int           len;
 
   spec = chtml20->spec;
@@ -506,7 +506,7 @@ chtml20_search_emoji(Chtml20* chtml20, char* txt, char** rslt)
  * @return The conversion result is returned.
  */
 static char*
-chtml20_start_html_tag(Chtml20* chtml20, Node* node) 
+s_chtml20_start_html_tag(chtml20_t* chtml20, Node* node) 
 {
   Doc*          doc   = chtml20->doc;
   request_rec*  r     = doc->r;
@@ -528,7 +528,7 @@ chtml20_start_html_tag(Chtml20* chtml20, Node* node)
  * @return The conversion result is returned.
  */
 static char*
-chtml20_end_html_tag(Chtml20* chtml20, Node* child) 
+s_chtml20_end_html_tag(chtml20_t* chtml20, Node* child) 
 {
   Doc*          doc = chtml20->doc;
   request_rec*  r   = doc->r;
@@ -547,7 +547,7 @@ chtml20_end_html_tag(Chtml20* chtml20, Node* child)
  * @return The conversion result is returned.
  */
 static char*
-chtml20_start_meta_tag(Chtml20* chtml20, Node* node) 
+s_chtml20_start_meta_tag(chtml20_t* chtml20, Node* node) 
 {
   Doc* doc = chtml20->doc;
   request_rec* r = doc->r;
@@ -604,7 +604,7 @@ chtml20_start_meta_tag(Chtml20* chtml20, Node* node)
  * @return The conversion result is returned.
  */
 static char*
-chtml20_end_meta_tag(Chtml20* chtml20, Node* child) 
+s_chtml20_end_meta_tag(chtml20_t* chtml20, Node* child) 
 {
   return chtml20->out;
 }
@@ -618,7 +618,7 @@ chtml20_end_meta_tag(Chtml20* chtml20, Node* child)
  * @return The conversion result is returned.
  */
 static char*
-chtml20_start_head_tag(Chtml20* chtml20, Node* node) 
+s_chtml20_start_head_tag(chtml20_t* chtml20, Node* node) 
 {
   Doc*          doc = chtml20->doc;
   request_rec*  r   = doc->r;
@@ -636,7 +636,7 @@ chtml20_start_head_tag(Chtml20* chtml20, Node* node)
  * @return The conversion result is returned.
  */
 static char*
-chtml20_end_head_tag(Chtml20* chtml20, Node* child) 
+s_chtml20_end_head_tag(chtml20_t* chtml20, Node* child) 
 {
   Doc*          doc = chtml20->doc;
   request_rec*  r   = doc->r;
@@ -654,7 +654,7 @@ chtml20_end_head_tag(Chtml20* chtml20, Node* child)
  * @return The conversion result is returned.
  */
 static char*
-chtml20_start_title_tag(Chtml20* chtml20, Node* node) 
+s_chtml20_start_title_tag(chtml20_t* chtml20, Node* node) 
 {
   Doc* doc = chtml20->doc;
   request_rec* r = doc->r;
@@ -672,7 +672,7 @@ chtml20_start_title_tag(Chtml20* chtml20, Node* node)
  * @return The conversion result is returned.
  */
 static char*
-chtml20_end_title_tag(Chtml20* chtml20, Node* child) 
+s_chtml20_end_title_tag(chtml20_t* chtml20, Node* child) 
 {
   Doc*          doc = chtml20->doc;
   request_rec*  r   = doc->r;
@@ -691,7 +691,7 @@ chtml20_end_title_tag(Chtml20* chtml20, Node* child)
  * @return The conversion result is returned.
  */
 static char*
-chtml20_start_base_tag(Chtml20* chtml20, Node* node) 
+s_chtml20_start_base_tag(chtml20_t* chtml20, Node* node) 
 {
   Attr*         attr;
   Doc*          doc   = chtml20->doc;
@@ -731,7 +731,7 @@ chtml20_start_base_tag(Chtml20* chtml20, Node* node)
  * @return The conversion result is returned.
  */
 static char*
-chtml20_end_base_tag(Chtml20* chtml20, Node* child) 
+s_chtml20_end_base_tag(chtml20_t* chtml20, Node* child) 
 {
   return chtml20->out;
 }
@@ -745,7 +745,7 @@ chtml20_end_base_tag(Chtml20* chtml20, Node* child)
  * @return The conversion result is returned.
  */
 static char*
-chtml20_start_body_tag(Chtml20* chtml20, Node* node) 
+s_chtml20_start_body_tag(chtml20_t* chtml20, Node* node) 
 {
   Doc* doc = chtml20->doc;
   request_rec* r = doc->r;
@@ -832,7 +832,7 @@ chtml20_start_body_tag(Chtml20* chtml20, Node* node)
  * @return The conversion result is returned.
  */
 static char*
-chtml20_end_body_tag(Chtml20* chtml20, Node* child) 
+s_chtml20_end_body_tag(chtml20_t* chtml20, Node* child) 
 {
   Doc*          doc = chtml20->doc;
   request_rec*  r = doc->r;
@@ -851,7 +851,7 @@ chtml20_end_body_tag(Chtml20* chtml20, Node* child)
  * @return The conversion result is returned.
  */
 static char*
-chtml20_start_a_tag(Chtml20* chtml20, Node* node) 
+s_chtml20_start_a_tag(chtml20_t* chtml20, Node* node) 
 {
   Doc*          doc   = chtml20->doc;
   request_rec*  r     = doc->r;
@@ -1006,7 +1006,7 @@ chtml20_start_a_tag(Chtml20* chtml20, Node* node)
  * @return The conversion result is returned.
  */
 static char*
-chtml20_end_a_tag(Chtml20* chtml20, Node* child) 
+s_chtml20_end_a_tag(chtml20_t* chtml20, Node* child) 
 {
   Doc* doc = chtml20->doc;
   request_rec* r = doc->r;
@@ -1024,7 +1024,7 @@ chtml20_end_a_tag(Chtml20* chtml20, Node* child)
  * @return The conversion result is returned.
  */
 static char*
-chtml20_start_br_tag(Chtml20* chtml20, Node* node) 
+s_chtml20_start_br_tag(chtml20_t* chtml20, Node* node) 
 {
   Doc* doc = chtml20->doc;
   request_rec* r = doc->r;
@@ -1041,7 +1041,7 @@ chtml20_start_br_tag(Chtml20* chtml20, Node* node)
  * @return The conversion result is returned.
  */
 static char*
-chtml20_end_br_tag(Chtml20* chtml20, Node* child) 
+s_chtml20_end_br_tag(chtml20_t* chtml20, Node* child) 
 {
   return chtml20->out;
 }
@@ -1055,7 +1055,7 @@ chtml20_end_br_tag(Chtml20* chtml20, Node* child)
  * @return The conversion result is returned.
  */
 static char*
-chtml20_start_font_tag(Chtml20* chtml20, Node* node) 
+s_chtml20_start_font_tag(chtml20_t* chtml20, Node* node) 
 {
   Doc*          doc   = chtml20->doc;
   request_rec*  r     = doc->r;
@@ -1105,7 +1105,7 @@ chtml20_start_font_tag(Chtml20* chtml20, Node* node)
  * @return The conversion result is returned.
  */
 static char*
-chtml20_end_font_tag(Chtml20* chtml20, Node* child) 
+s_chtml20_end_font_tag(chtml20_t* chtml20, Node* child) 
 {
   request_rec* r = chtml20->doc->r;
   chtml20->out = apr_pstrcat(r->pool, chtml20->out, "</font>", NULL);
@@ -1121,7 +1121,7 @@ chtml20_end_font_tag(Chtml20* chtml20, Node* child)
  * @return The conversion result is returned.
  */
 static char*
-chtml20_start_form_tag(Chtml20* chtml20, Node* node) 
+s_chtml20_start_form_tag(chtml20_t* chtml20, Node* node) 
 {
   Doc* doc = chtml20->doc;
   request_rec* r = doc->r;
@@ -1185,7 +1185,7 @@ chtml20_start_form_tag(Chtml20* chtml20, Node* node)
  * @return The conversion result is returned.
  */
 static char*
-chtml20_end_form_tag(Chtml20* chtml20, Node* child) 
+s_chtml20_end_form_tag(chtml20_t* chtml20, Node* child) 
 {
   Doc* doc = chtml20->doc;
   request_rec* r = doc->r;
@@ -1203,7 +1203,7 @@ chtml20_end_form_tag(Chtml20* chtml20, Node* child)
  * @return The conversion result is returned.
  */
 static char*
-chtml20_start_input_tag(Chtml20* chtml20, Node* node) 
+s_chtml20_start_input_tag(chtml20_t* chtml20, Node* node) 
 {
   Doc*          doc         = chtml20->doc;
   request_rec*  r           = doc->r;
@@ -1328,7 +1328,7 @@ chtml20_start_input_tag(Chtml20* chtml20, Node* node)
  * @return The conversion result is returned.
  */
 static char*
-chtml20_end_input_tag(Chtml20* chtml20, Node* child) 
+s_chtml20_end_input_tag(chtml20_t* chtml20, Node* child) 
 {
   return chtml20->out;
 }
@@ -1342,7 +1342,7 @@ chtml20_end_input_tag(Chtml20* chtml20, Node* child)
  * @return The conversion result is returned.
  */
 static char*
-chtml20_start_center_tag(Chtml20* chtml20, Node* node) 
+s_chtml20_start_center_tag(chtml20_t* chtml20, Node* node) 
 {
   Doc*          doc = chtml20->doc;
   request_rec*  r   = doc->r;
@@ -1361,7 +1361,7 @@ chtml20_start_center_tag(Chtml20* chtml20, Node* node)
  * @return The conversion result is returned.
  */
 static char*
-chtml20_end_center_tag(Chtml20* chtml20, Node* child) 
+s_chtml20_end_center_tag(chtml20_t* chtml20, Node* child) 
 {
   Doc*          doc = chtml20->doc;
   request_rec*  r   = doc->r;
@@ -1380,7 +1380,7 @@ chtml20_end_center_tag(Chtml20* chtml20, Node* child)
  * @return The conversion result is returned.
  */
 static char*
-chtml20_start_hr_tag(Chtml20* chtml20, Node* node) 
+s_chtml20_start_hr_tag(chtml20_t* chtml20, Node* node) 
 {
   Doc* doc = chtml20->doc;
   request_rec* r = doc->r;
@@ -1456,7 +1456,7 @@ chtml20_start_hr_tag(Chtml20* chtml20, Node* node)
  * @return The conversion result is returned.
  */
 static char*
-chtml20_end_hr_tag(Chtml20* chtml20, Node* child) 
+s_chtml20_end_hr_tag(chtml20_t* chtml20, Node* child) 
 {
   return chtml20->out;
 }
@@ -1470,13 +1470,13 @@ chtml20_end_hr_tag(Chtml20* chtml20, Node* child)
  * @return The conversion result is returned.
  */
 static char*
-chtml20_start_img_tag(Chtml20* chtml20, Node* node) 
+s_chtml20_start_img_tag(chtml20_t* chtml20, Node* node) 
 {
   Doc*          doc = chtml20->doc;
   request_rec*  r   = doc->r;
   Attr* attr;
 #ifndef IMG_NOT_CONVERT_FILENAME
-  device_table* spec = chtml20->spec;
+  device_table_t* spec = chtml20->spec;
 #endif
 
   chtml20->out = apr_pstrcat(r->pool, chtml20->out, "<img", NULL);
@@ -1585,7 +1585,7 @@ chtml20_start_img_tag(Chtml20* chtml20, Node* node)
  * @return The conversion result is returned.
  */
 static char*
-chtml20_end_img_tag(Chtml20* chtml20, Node* child) 
+s_chtml20_end_img_tag(chtml20_t* chtml20, Node* child) 
 {
   return chtml20->out;
 }
@@ -1599,7 +1599,7 @@ chtml20_end_img_tag(Chtml20* chtml20, Node* child)
  * @return The conversion result is returned.
  */
 static char*
-chtml20_start_select_tag(Chtml20* chtml20, Node* child)
+s_chtml20_start_select_tag(chtml20_t* chtml20, Node* child)
 {
   Doc* doc = chtml20->doc;
   request_rec* r = doc->r;
@@ -1662,7 +1662,7 @@ chtml20_start_select_tag(Chtml20* chtml20, Node* child)
  * @return The conversion result is returned.
  */
 static char*
-chtml20_end_select_tag(Chtml20* chtml20, Node* child)
+s_chtml20_end_select_tag(chtml20_t* chtml20, Node* child)
 {
   Doc* doc = chtml20->doc;
   request_rec* r = doc->r;
@@ -1680,7 +1680,7 @@ chtml20_end_select_tag(Chtml20* chtml20, Node* child)
  * @return The conversion result is returned.
  */
 static char*
-chtml20_start_option_tag(Chtml20* chtml20, Node* child)
+s_chtml20_start_option_tag(chtml20_t* chtml20, Node* child)
 {
   Doc* doc = chtml20->doc;
   request_rec* r = doc->r;
@@ -1741,7 +1741,7 @@ chtml20_start_option_tag(Chtml20* chtml20, Node* child)
  * @return The conversion result is returned.
  */
 static char*
-chtml20_end_option_tag(Chtml20* chtml20, Node* child)
+s_chtml20_end_option_tag(chtml20_t* chtml20, Node* child)
 {
   /* Don't close */
   return chtml20->out;
@@ -1756,7 +1756,7 @@ chtml20_end_option_tag(Chtml20* chtml20, Node* child)
  * @return The conversion result is returned.
  */
 static char*
-chtml20_start_div_tag(Chtml20* chtml20, Node* child)
+s_chtml20_start_div_tag(chtml20_t* chtml20, Node* child)
 {
   Doc* doc = chtml20->doc;
   request_rec* r = doc->r;
@@ -1800,7 +1800,7 @@ chtml20_start_div_tag(Chtml20* chtml20, Node* child)
  * @return The conversion result is returned.
  */
 static char*
-chtml20_end_div_tag(Chtml20* chtml20, Node* child)
+s_chtml20_end_div_tag(chtml20_t* chtml20, Node* child)
 {
   Doc* doc = chtml20->doc;
   request_rec* r = doc->r;
@@ -1812,7 +1812,7 @@ chtml20_end_div_tag(Chtml20* chtml20, Node* child)
 
 
 static void
-chtml20_chxjif_tag(Chtml20* chtml20, Node* node)
+s_chtml20_chxjif_tag(chtml20_t* chtml20, Node* node)
 {
   Doc*         doc   = chtml20->doc;
   Node*        child;
@@ -1823,7 +1823,7 @@ chtml20_chxjif_tag(Chtml20* chtml20, Node* node)
        child = qs_get_next_node(doc, child))
   {
     chtml20->out = apr_pstrcat(r->pool, chtml20->out, child->otext, NULL);
-    chtml20_chxjif_tag(chtml20, child);
+    s_chtml20_chxjif_tag(chtml20, child);
   }
 }
 /*
