@@ -21,44 +21,44 @@
 #include "chxj_img_conv.h"
 #include "chxj_qr_code.h"
 
-static char* chtml30_node_exchange    (Chtml30* chtml, Node* node, int indent);
-static char* chtml30_start_html_tag   (Chtml30* chtml, Node* child);
-static char* chtml30_end_html_tag     (Chtml30* chtml, Node* child);
-static char* chtml30_start_meta_tag   (Chtml30* chtml, Node* node);
-static char* chtml30_end_meta_tag     (Chtml30* chtml, Node* node);
-static char* chtml30_start_head_tag   (Chtml30* chtml, Node* node);
-static char* chtml30_end_head_tag     (Chtml30* chtml, Node* node);
-static char* chtml30_start_title_tag  (Chtml30* chtml, Node* node);
-static char* chtml30_end_title_tag    (Chtml30* chtml, Node* node);
-static char* chtml30_start_base_tag   (Chtml30* chtml, Node* node);
-static char* chtml30_end_base_tag     (Chtml30* chtml, Node* node);
-static char* chtml30_start_body_tag   (Chtml30* chtml, Node* node);
-static char* chtml30_end_body_tag     (Chtml30* chtml, Node* node);
-static char* chtml30_start_a_tag      (Chtml30* chtml, Node* node);
-static char* chtml30_end_a_tag        (Chtml30* chtml, Node* node);
-static char* chtml30_start_br_tag     (Chtml30* chtml, Node* node);
-static char* chtml30_end_br_tag       (Chtml30* chtml, Node* node);
-static char* chtml30_start_font_tag   (Chtml30* chtml, Node* node);
-static char* chtml30_end_font_tag     (Chtml30* chtml, Node* node);
-static char* chtml30_start_form_tag   (Chtml30* chtml, Node* node);
-static char* chtml30_end_form_tag     (Chtml30* chtml, Node* node);
-static char* chtml30_start_input_tag  (Chtml30* chtml, Node* node);
-static char* chtml30_end_input_tag    (Chtml30* chtml, Node* node);
-static char* chtml30_start_center_tag (Chtml30* chtml, Node* node);
-static char* chtml30_end_center_tag   (Chtml30* chtml, Node* node);
-static char* chtml30_start_hr_tag     (Chtml30* chtml, Node* node);
-static char* chtml30_end_hr_tag       (Chtml30* chtml, Node* node);
-static char* chtml30_start_img_tag    (Chtml30* chtml, Node* node);
-static char* chtml30_end_img_tag      (Chtml30* chtml, Node* node);
-static char* chtml30_start_select_tag (Chtml30* chtml, Node* node);
-static char* chtml30_end_select_tag   (Chtml30* chtml, Node* node);
-static char* chtml30_start_option_tag (Chtml30* chtml, Node* node);
-static char* chtml30_end_option_tag   (Chtml30* chtml, Node* node);
-static char* chtml30_start_div_tag    (Chtml30* chtml, Node* node);
-static char* chtml30_end_div_tag      (Chtml30* chtml, Node* node);
-static void chxj_init_chtml30(Chtml30* chtml, Doc* doc, request_rec* r, device_table* spec);
-static int chtml30_search_emoji(Chtml30* chtml, char* txt, char** rslt);
-static void chtml30_chxjif_tag(Chtml30* chtml, Node* node); 
+static char* s_chtml30_node_exchange    (chtml30_t* chtml, Node* node, int indent);
+static char* s_chtml30_start_html_tag   (chtml30_t* chtml, Node* child);
+static char* s_chtml30_end_html_tag     (chtml30_t* chtml, Node* child);
+static char* s_chtml30_start_meta_tag   (chtml30_t* chtml, Node* node);
+static char* s_chtml30_end_meta_tag     (chtml30_t* chtml, Node* node);
+static char* s_chtml30_start_head_tag   (chtml30_t* chtml, Node* node);
+static char* s_chtml30_end_head_tag     (chtml30_t* chtml, Node* node);
+static char* s_chtml30_start_title_tag  (chtml30_t* chtml, Node* node);
+static char* s_chtml30_end_title_tag    (chtml30_t* chtml, Node* node);
+static char* s_chtml30_start_base_tag   (chtml30_t* chtml, Node* node);
+static char* s_chtml30_end_base_tag     (chtml30_t* chtml, Node* node);
+static char* s_chtml30_start_body_tag   (chtml30_t* chtml, Node* node);
+static char* s_chtml30_end_body_tag     (chtml30_t* chtml, Node* node);
+static char* s_chtml30_start_a_tag      (chtml30_t* chtml, Node* node);
+static char* s_chtml30_end_a_tag        (chtml30_t* chtml, Node* node);
+static char* s_chtml30_start_br_tag     (chtml30_t* chtml, Node* node);
+static char* s_chtml30_end_br_tag       (chtml30_t* chtml, Node* node);
+static char* s_chtml30_start_font_tag   (chtml30_t* chtml, Node* node);
+static char* s_chtml30_end_font_tag     (chtml30_t* chtml, Node* node);
+static char* s_chtml30_start_form_tag   (chtml30_t* chtml, Node* node);
+static char* s_chtml30_end_form_tag     (chtml30_t* chtml, Node* node);
+static char* s_chtml30_start_input_tag  (chtml30_t* chtml, Node* node);
+static char* s_chtml30_end_input_tag    (chtml30_t* chtml, Node* node);
+static char* s_chtml30_start_center_tag (chtml30_t* chtml, Node* node);
+static char* s_chtml30_end_center_tag   (chtml30_t* chtml, Node* node);
+static char* s_chtml30_start_hr_tag     (chtml30_t* chtml, Node* node);
+static char* s_chtml30_end_hr_tag       (chtml30_t* chtml, Node* node);
+static char* s_chtml30_start_img_tag    (chtml30_t* chtml, Node* node);
+static char* s_chtml30_end_img_tag      (chtml30_t* chtml, Node* node);
+static char* s_chtml30_start_select_tag (chtml30_t* chtml, Node* node);
+static char* s_chtml30_end_select_tag   (chtml30_t* chtml, Node* node);
+static char* s_chtml30_start_option_tag (chtml30_t* chtml, Node* node);
+static char* s_chtml30_end_option_tag   (chtml30_t* chtml, Node* node);
+static char* s_chtml30_start_div_tag    (chtml30_t* chtml, Node* node);
+static char* s_chtml30_end_div_tag      (chtml30_t* chtml, Node* node);
+static void  s_init_chtml30(chtml30_t* chtml, Doc* doc, request_rec* r, device_table_t* spec);
+static int   s_chtml30_search_emoji(chtml30_t* chtml, char* txt, char** rslt);
+static void  s_chtml30_chxjif_tag(chtml30_t* chtml, Node* node); 
 
 /**
  * converts from CHTML5.0 to CHTML3.0.
@@ -72,14 +72,14 @@ static void chtml30_chxjif_tag(Chtml30* chtml, Node* node);
 char*
 chxj_exchange_chtml30(
   request_rec* r,
-  device_table *spec,
+  device_table_t* spec,
   const char* src,
   apr_size_t srclen,
   apr_size_t *dstlen)
 {
   char*     dst = NULL;
   char*     ss;
-  Chtml30   chtml30;
+  chtml30_t   chtml30;
   Doc       doc;
 
 
@@ -98,7 +98,7 @@ chxj_exchange_chtml30(
   /*--------------------------------------------------------------------------*/
   /* The CHTML structure is initialized.                                      */
   /*--------------------------------------------------------------------------*/
-  chxj_init_chtml30(&chtml30, &doc, r, spec);
+  s_init_chtml30(&chtml30, &doc, r, spec);
   ap_set_content_type(r, "text/html; charset=Windows-31J");
 
   /*--------------------------------------------------------------------------*/
@@ -120,7 +120,7 @@ chxj_exchange_chtml30(
   /*--------------------------------------------------------------------------*/
   /* It converts it from CHTML to CHTML.                                      */
   /*--------------------------------------------------------------------------*/
-  dst = chtml30_node_exchange(&chtml30, qs_get_root(&doc), 0);
+  dst = s_chtml30_node_exchange(&chtml30, qs_get_root(&doc), 0);
   qs_all_free(&doc,QX_LOGMARK);
 
   if (dst == NULL) 
@@ -150,10 +150,10 @@ chxj_exchange_chtml30(
  * @param spec  [i]   The pointer to the device_table
  */
 static void
-chxj_init_chtml30(Chtml30* chtml30, Doc* doc, request_rec* r, device_table* spec)
+s_init_chtml30(chtml30_t* chtml30, Doc* doc, request_rec* r, device_table_t* spec)
 {
   memset(doc,   0, sizeof(Doc));
-  memset(chtml30, 0, sizeof(Chtml30));
+  memset(chtml30, 0, sizeof(chtml30_t));
 
   doc->r      = r;
   chtml30->doc  = doc;
@@ -173,7 +173,7 @@ chxj_init_chtml30(Chtml30* chtml30, Doc* doc, request_rec* r, device_table* spec
  * @return The character string after it converts it is returned. 
  */
 static char*
-chtml30_node_exchange(Chtml30* chtml30, Node* node, int indent) 
+s_chtml30_node_exchange(chtml30_t* chtml30, Node* node, int indent) 
 {
   Node*         child;
   Doc*          doc   = chtml30->doc;
@@ -193,9 +193,9 @@ chtml30_node_exchange(Chtml30* chtml30, Node* node, int indent)
     /*------------------------------------------------------------------------*/
     if (strcasecmp(name, "html") == 0) 
     {
-      chtml30_start_html_tag(chtml30, child);
-      chtml30_node_exchange (chtml30, child,indent+1);
-      chtml30_end_html_tag  (chtml30, child);
+      s_chtml30_start_html_tag(chtml30, child);
+      s_chtml30_node_exchange (chtml30, child,indent+1);
+      s_chtml30_end_html_tag  (chtml30, child);
     }
     /*------------------------------------------------------------------------*/
     /* <META>                                                                 */
@@ -203,8 +203,8 @@ chtml30_node_exchange(Chtml30* chtml30, Node* node, int indent)
     else
     if (strcasecmp(name, "meta") == 0) 
     {
-      chtml30_start_meta_tag(chtml30, child);
-      chtml30_end_meta_tag  (chtml30, child);
+      s_chtml30_start_meta_tag(chtml30, child);
+      s_chtml30_end_meta_tag  (chtml30, child);
     }
     /*------------------------------------------------------------------------*/
     /* <HEAD>                                                                 */
@@ -212,9 +212,9 @@ chtml30_node_exchange(Chtml30* chtml30, Node* node, int indent)
     else
     if (strcasecmp(name, "head") == 0) 
     {
-      chtml30_start_head_tag(chtml30, child);
-      chtml30_node_exchange (chtml30, child,indent+1);
-      chtml30_end_head_tag  (chtml30, child);
+      s_chtml30_start_head_tag(chtml30, child);
+      s_chtml30_node_exchange (chtml30, child,indent+1);
+      s_chtml30_end_head_tag  (chtml30, child);
     }
     /*------------------------------------------------------------------------*/
     /* <TITLE>                                                                */
@@ -222,9 +222,9 @@ chtml30_node_exchange(Chtml30* chtml30, Node* node, int indent)
     else
     if (strcasecmp(name, "title") == 0) 
     {
-      chtml30_start_title_tag (chtml30, child);
-      chtml30_node_exchange   (chtml30, child,indent+1);
-      chtml30_end_title_tag   (chtml30, child);
+      s_chtml30_start_title_tag (chtml30, child);
+      s_chtml30_node_exchange   (chtml30, child,indent+1);
+      s_chtml30_end_title_tag   (chtml30, child);
     }
     /*------------------------------------------------------------------------*/
     /* <BASE>                                                                 */
@@ -232,8 +232,8 @@ chtml30_node_exchange(Chtml30* chtml30, Node* node, int indent)
     else
     if (strcasecmp(name, "base") == 0) 
     {
-      chtml30_start_base_tag(chtml30, child);
-      chtml30_end_base_tag  (chtml30, child);
+      s_chtml30_start_base_tag(chtml30, child);
+      s_chtml30_end_base_tag  (chtml30, child);
     }
     /*------------------------------------------------------------------------*/
     /* <BODY>                                                                 */
@@ -241,9 +241,9 @@ chtml30_node_exchange(Chtml30* chtml30, Node* node, int indent)
     else
     if (strcasecmp(name, "body") == 0) 
     {
-      chtml30_start_body_tag(chtml30, child);
-      chtml30_node_exchange (chtml30, child,indent+1);
-      chtml30_end_body_tag  (chtml30, child);
+      s_chtml30_start_body_tag(chtml30, child);
+      s_chtml30_node_exchange (chtml30, child,indent+1);
+      s_chtml30_end_body_tag  (chtml30, child);
     }
     /*------------------------------------------------------------------------*/
     /* <A>                                                                    */
@@ -251,9 +251,9 @@ chtml30_node_exchange(Chtml30* chtml30, Node* node, int indent)
     else
     if (strcasecmp(name, "a") == 0) 
     {
-      chtml30_start_a_tag   (chtml30, child);
-      chtml30_node_exchange (chtml30, child,indent+1);
-      chtml30_end_a_tag     (chtml30, child);
+      s_chtml30_start_a_tag   (chtml30, child);
+      s_chtml30_node_exchange (chtml30, child,indent+1);
+      s_chtml30_end_a_tag     (chtml30, child);
     }
     /*------------------------------------------------------------------------*/
     /* <BR>                                                                   */
@@ -261,9 +261,9 @@ chtml30_node_exchange(Chtml30* chtml30, Node* node, int indent)
     else
     if (strcasecmp(name, "br") == 0) 
     {
-      chtml30_start_br_tag  (chtml30, child);
-      chtml30_node_exchange (chtml30, child,indent+1);
-      chtml30_end_br_tag    (chtml30, child);
+      s_chtml30_start_br_tag  (chtml30, child);
+      s_chtml30_node_exchange (chtml30, child,indent+1);
+      s_chtml30_end_br_tag    (chtml30, child);
     }
     /*------------------------------------------------------------------------*/
     /* <FONT>                                                                 */
@@ -271,9 +271,9 @@ chtml30_node_exchange(Chtml30* chtml30, Node* node, int indent)
     else
     if (strcasecmp(name, "font") == 0) 
     {
-      chtml30_start_font_tag(chtml30, child);
-      chtml30_node_exchange (chtml30, child,indent+1);
-      chtml30_end_font_tag  (chtml30, child);
+      s_chtml30_start_font_tag(chtml30, child);
+      s_chtml30_node_exchange (chtml30, child,indent+1);
+      s_chtml30_end_font_tag  (chtml30, child);
     }
     /*------------------------------------------------------------------------*/
     /* <FORM>                                                                 */
@@ -281,9 +281,9 @@ chtml30_node_exchange(Chtml30* chtml30, Node* node, int indent)
     else
     if (strcasecmp(name, "form") == 0) 
     {
-      chtml30_start_form_tag(chtml30, child);
-      chtml30_node_exchange (chtml30, child,indent+1);
-      chtml30_end_form_tag  (chtml30, child);
+      s_chtml30_start_form_tag(chtml30, child);
+      s_chtml30_node_exchange (chtml30, child,indent+1);
+      s_chtml30_end_form_tag  (chtml30, child);
     }
     /*------------------------------------------------------------------------*/
     /* <INPUT>                                                                */
@@ -291,9 +291,9 @@ chtml30_node_exchange(Chtml30* chtml30, Node* node, int indent)
     else
     if (strcasecmp(name, "input") == 0) 
     {
-      chtml30_start_input_tag (chtml30, child);
-      chtml30_node_exchange   (chtml30, child,indent+1);
-      chtml30_end_input_tag   (chtml30, child);
+      s_chtml30_start_input_tag (chtml30, child);
+      s_chtml30_node_exchange   (chtml30, child,indent+1);
+      s_chtml30_end_input_tag   (chtml30, child);
     }
     /*------------------------------------------------------------------------*/
     /* <HR>                                                                   */
@@ -301,8 +301,8 @@ chtml30_node_exchange(Chtml30* chtml30, Node* node, int indent)
     else
     if (strcasecmp(name, "hr") == 0) 
     {
-      chtml30_start_hr_tag  (chtml30, child);
-      chtml30_end_hr_tag    (chtml30, child);
+      s_chtml30_start_hr_tag  (chtml30, child);
+      s_chtml30_end_hr_tag    (chtml30, child);
     }
     /*------------------------------------------------------------------------*/
     /* <CENTER>                                                               */
@@ -310,9 +310,9 @@ chtml30_node_exchange(Chtml30* chtml30, Node* node, int indent)
     else
     if (strcasecmp(name, "center") == 0) 
     {
-      chtml30_start_center_tag(chtml30, child);
-      chtml30_node_exchange   (chtml30, child,indent+1);
-      chtml30_end_center_tag  (chtml30, child);
+      s_chtml30_start_center_tag(chtml30, child);
+      s_chtml30_node_exchange   (chtml30, child,indent+1);
+      s_chtml30_end_center_tag  (chtml30, child);
     }
     /*------------------------------------------------------------------------*/
     /* <IMG>                                                                  */
@@ -320,8 +320,8 @@ chtml30_node_exchange(Chtml30* chtml30, Node* node, int indent)
     else
     if (strcasecmp(name, "img") == 0) 
     {
-      chtml30_start_img_tag (chtml30, child);
-      chtml30_end_img_tag   (chtml30, child);
+      s_chtml30_start_img_tag (chtml30, child);
+      s_chtml30_end_img_tag   (chtml30, child);
     }
     /*------------------------------------------------------------------------*/
     /* <SELECT>                                                               */
@@ -329,9 +329,9 @@ chtml30_node_exchange(Chtml30* chtml30, Node* node, int indent)
     else
     if (strcasecmp(name, "select") == 0)
     {
-      chtml30_start_select_tag(chtml30, child);
-      chtml30_node_exchange   (chtml30, child, indent+1);
-      chtml30_end_select_tag  (chtml30, child);
+      s_chtml30_start_select_tag(chtml30, child);
+      s_chtml30_node_exchange   (chtml30, child, indent+1);
+      s_chtml30_end_select_tag  (chtml30, child);
     }
     /*------------------------------------------------------------------------*/
     /* <OPTION>                                                               */
@@ -339,9 +339,9 @@ chtml30_node_exchange(Chtml30* chtml30, Node* node, int indent)
     else
     if (strcasecmp(name, "option") == 0)
     {
-      chtml30_start_option_tag(chtml30, child);
-      chtml30_node_exchange   (chtml30, child, indent+1);
-      chtml30_end_option_tag  (chtml30, child);
+      s_chtml30_start_option_tag(chtml30, child);
+      s_chtml30_node_exchange   (chtml30, child, indent+1);
+      s_chtml30_end_option_tag  (chtml30, child);
     }
     /*------------------------------------------------------------------------*/
     /* <DIV>                                                                  */
@@ -349,9 +349,9 @@ chtml30_node_exchange(Chtml30* chtml30, Node* node, int indent)
     else
     if (strcasecmp(name, "div") == 0)
     {
-      chtml30_start_div_tag (chtml30, child);
-      chtml30_node_exchange (chtml30, child, indent+1);
-      chtml30_end_div_tag   (chtml30, child);
+      s_chtml30_start_div_tag (chtml30, child);
+      s_chtml30_node_exchange (chtml30, child, indent+1);
+      s_chtml30_end_div_tag   (chtml30, child);
     }
     /*------------------------------------------------------------------------*/
     /* <BLINK>                                                                */
@@ -375,11 +375,11 @@ chtml30_node_exchange(Chtml30* chtml30, Node* node, int indent)
         parse_attr = qs_get_parse_attr(doc, child, r);
         if (parse_attr != NULL && strcasecmp(parse_attr, "true") == 0)
         {
-          chtml30_node_exchange (chtml30, child, indent+1);
+          s_chtml30_node_exchange (chtml30, child, indent+1);
         }
         else
         {
-          chtml30_chxjif_tag(chtml30, child);
+          s_chtml30_chxjif_tag(chtml30, child);
         }
       }
     }
@@ -413,7 +413,7 @@ chtml30_node_exchange(Chtml30* chtml30, Node* node, int indent)
       for (ii=0; ii<qs_get_node_size(doc,child); ii++)
       {
         char* out;
-        int rtn = chtml30_search_emoji(chtml30, &textval[ii], &out);
+        int rtn = s_chtml30_search_emoji(chtml30, &textval[ii], &out);
         if (rtn != 0)
         {
           tdst = qs_out_apr_pstrcat(r, tdst, out, &tdst_len);
@@ -452,11 +452,11 @@ chtml30_node_exchange(Chtml30* chtml30, Node* node, int indent)
  * @return When corresponding EMOJI exists, it returns it excluding 0. 
  */
 static int
-chtml30_search_emoji(Chtml30* chtml30, char* txt, char** rslt)
+s_chtml30_search_emoji(chtml30_t* chtml30, char* txt, char** rslt)
 {
   emoji_t*      ee;
   request_rec*  r;
-  device_table* spec;
+  device_table_t* spec;
   int           len;
 
   spec = chtml30->spec;
@@ -508,7 +508,7 @@ chtml30_search_emoji(Chtml30* chtml30, char* txt, char** rslt)
  * @return The conversion result is returned.
  */
 static char*
-chtml30_start_html_tag(Chtml30* chtml30, Node* node) 
+s_chtml30_start_html_tag(chtml30_t* chtml30, Node* node) 
 {
   Doc*          doc   = chtml30->doc;
   request_rec*  r     = doc->r;
@@ -530,7 +530,7 @@ chtml30_start_html_tag(Chtml30* chtml30, Node* node)
  * @return The conversion result is returned.
  */
 static char*
-chtml30_end_html_tag(Chtml30* chtml30, Node* child) 
+s_chtml30_end_html_tag(chtml30_t* chtml30, Node* child) 
 {
   Doc*          doc = chtml30->doc;
   request_rec*  r   = doc->r;
@@ -549,7 +549,7 @@ chtml30_end_html_tag(Chtml30* chtml30, Node* child)
  * @return The conversion result is returned.
  */
 static char*
-chtml30_start_meta_tag(Chtml30* chtml30, Node* node) 
+s_chtml30_start_meta_tag(chtml30_t* chtml30, Node* node) 
 {
   Doc* doc = chtml30->doc;
   request_rec* r = doc->r;
@@ -606,7 +606,7 @@ chtml30_start_meta_tag(Chtml30* chtml30, Node* node)
  * @return The conversion result is returned.
  */
 static char*
-chtml30_end_meta_tag(Chtml30* chtml30, Node* child) 
+s_chtml30_end_meta_tag(chtml30_t* chtml30, Node* child) 
 {
   return chtml30->out;
 }
@@ -620,7 +620,7 @@ chtml30_end_meta_tag(Chtml30* chtml30, Node* child)
  * @return The conversion result is returned.
  */
 static char*
-chtml30_start_head_tag(Chtml30* chtml30, Node* node) 
+s_chtml30_start_head_tag(chtml30_t* chtml30, Node* node) 
 {
   Doc*          doc = chtml30->doc;
   request_rec*  r   = doc->r;
@@ -638,7 +638,7 @@ chtml30_start_head_tag(Chtml30* chtml30, Node* node)
  * @return The conversion result is returned.
  */
 static char*
-chtml30_end_head_tag(Chtml30* chtml30, Node* child) 
+s_chtml30_end_head_tag(chtml30_t* chtml30, Node* child) 
 {
   Doc*          doc = chtml30->doc;
   request_rec*  r   = doc->r;
@@ -656,7 +656,7 @@ chtml30_end_head_tag(Chtml30* chtml30, Node* child)
  * @return The conversion result is returned.
  */
 static char*
-chtml30_start_title_tag(Chtml30* chtml30, Node* node) 
+s_chtml30_start_title_tag(chtml30_t* chtml30, Node* node) 
 {
   Doc* doc = chtml30->doc;
   request_rec* r = doc->r;
@@ -674,7 +674,7 @@ chtml30_start_title_tag(Chtml30* chtml30, Node* node)
  * @return The conversion result is returned.
  */
 static char*
-chtml30_end_title_tag(Chtml30* chtml30, Node* child) 
+s_chtml30_end_title_tag(chtml30_t* chtml30, Node* child) 
 {
   Doc*          doc = chtml30->doc;
   request_rec*  r   = doc->r;
@@ -693,7 +693,7 @@ chtml30_end_title_tag(Chtml30* chtml30, Node* child)
  * @return The conversion result is returned.
  */
 static char*
-chtml30_start_base_tag(Chtml30* chtml30, Node* node) 
+s_chtml30_start_base_tag(chtml30_t* chtml30, Node* node) 
 {
   Attr*         attr;
   Doc*          doc   = chtml30->doc;
@@ -733,7 +733,7 @@ chtml30_start_base_tag(Chtml30* chtml30, Node* node)
  * @return The conversion result is returned.
  */
 static char*
-chtml30_end_base_tag(Chtml30* chtml30, Node* child) 
+s_chtml30_end_base_tag(chtml30_t* chtml30, Node* child) 
 {
   return chtml30->out;
 }
@@ -747,7 +747,7 @@ chtml30_end_base_tag(Chtml30* chtml30, Node* child)
  * @return The conversion result is returned.
  */
 static char*
-chtml30_start_body_tag(Chtml30* chtml30, Node* node) 
+s_chtml30_start_body_tag(chtml30_t* chtml30, Node* node) 
 {
   Doc* doc = chtml30->doc;
   request_rec* r = doc->r;
@@ -834,7 +834,7 @@ chtml30_start_body_tag(Chtml30* chtml30, Node* node)
  * @return The conversion result is returned.
  */
 static char*
-chtml30_end_body_tag(Chtml30* chtml30, Node* child) 
+s_chtml30_end_body_tag(chtml30_t* chtml30, Node* child) 
 {
   Doc*          doc = chtml30->doc;
   request_rec*  r = doc->r;
@@ -853,7 +853,7 @@ chtml30_end_body_tag(Chtml30* chtml30, Node* child)
  * @return The conversion result is returned.
  */
 static char*
-chtml30_start_a_tag(Chtml30* chtml30, Node* node) 
+s_chtml30_start_a_tag(chtml30_t* chtml30, Node* node) 
 {
   Doc*          doc   = chtml30->doc;
   request_rec*  r     = doc->r;
@@ -1012,7 +1012,7 @@ chtml30_start_a_tag(Chtml30* chtml30, Node* node)
  * @return The conversion result is returned.
  */
 static char*
-chtml30_end_a_tag(Chtml30* chtml30, Node* child) 
+s_chtml30_end_a_tag(chtml30_t* chtml30, Node* child) 
 {
   Doc* doc = chtml30->doc;
   request_rec* r = doc->r;
@@ -1030,7 +1030,7 @@ chtml30_end_a_tag(Chtml30* chtml30, Node* child)
  * @return The conversion result is returned.
  */
 static char*
-chtml30_start_br_tag(Chtml30* chtml30, Node* node) 
+s_chtml30_start_br_tag(chtml30_t* chtml30, Node* node) 
 {
   Doc* doc = chtml30->doc;
   request_rec* r = doc->r;
@@ -1047,7 +1047,7 @@ chtml30_start_br_tag(Chtml30* chtml30, Node* node)
  * @return The conversion result is returned.
  */
 static char*
-chtml30_end_br_tag(Chtml30* chtml30, Node* child) 
+s_chtml30_end_br_tag(chtml30_t* chtml30, Node* child) 
 {
   return chtml30->out;
 }
@@ -1061,7 +1061,7 @@ chtml30_end_br_tag(Chtml30* chtml30, Node* child)
  * @return The conversion result is returned.
  */
 static char*
-chtml30_start_font_tag(Chtml30* chtml30, Node* node) 
+s_chtml30_start_font_tag(chtml30_t* chtml30, Node* node) 
 {
   Doc*          doc   = chtml30->doc;
   request_rec*  r     = doc->r;
@@ -1111,7 +1111,7 @@ chtml30_start_font_tag(Chtml30* chtml30, Node* node)
  * @return The conversion result is returned.
  */
 static char*
-chtml30_end_font_tag(Chtml30* chtml30, Node* child) 
+s_chtml30_end_font_tag(chtml30_t* chtml30, Node* child) 
 {
   request_rec* r = chtml30->doc->r;
   chtml30->out = apr_pstrcat(r->pool, chtml30->out, "</font>", NULL);
@@ -1127,7 +1127,7 @@ chtml30_end_font_tag(Chtml30* chtml30, Node* child)
  * @return The conversion result is returned.
  */
 static char*
-chtml30_start_form_tag(Chtml30* chtml30, Node* node) 
+s_chtml30_start_form_tag(chtml30_t* chtml30, Node* node) 
 {
   Doc* doc = chtml30->doc;
   request_rec* r = doc->r;
@@ -1195,7 +1195,7 @@ chtml30_start_form_tag(Chtml30* chtml30, Node* node)
  * @return The conversion result is returned.
  */
 static char*
-chtml30_end_form_tag(Chtml30* chtml30, Node* child) 
+s_chtml30_end_form_tag(chtml30_t* chtml30, Node* child) 
 {
   Doc* doc = chtml30->doc;
   request_rec* r = doc->r;
@@ -1213,7 +1213,7 @@ chtml30_end_form_tag(Chtml30* chtml30, Node* child)
  * @return The conversion result is returned.
  */
 static char*
-chtml30_start_input_tag(Chtml30* chtml30, Node* node) 
+s_chtml30_start_input_tag(chtml30_t* chtml30, Node* node) 
 {
   Doc*          doc         = chtml30->doc;
   request_rec*  r           = doc->r;
@@ -1341,7 +1341,7 @@ chtml30_start_input_tag(Chtml30* chtml30, Node* node)
  * @return The conversion result is returned.
  */
 static char*
-chtml30_end_input_tag(Chtml30* chtml30, Node* child) 
+s_chtml30_end_input_tag(chtml30_t* chtml30, Node* child) 
 {
   return chtml30->out;
 }
@@ -1355,7 +1355,7 @@ chtml30_end_input_tag(Chtml30* chtml30, Node* child)
  * @return The conversion result is returned.
  */
 static char*
-chtml30_start_center_tag(Chtml30* chtml30, Node* node) 
+s_chtml30_start_center_tag(chtml30_t* chtml30, Node* node) 
 {
   Doc*          doc = chtml30->doc;
   request_rec*  r   = doc->r;
@@ -1374,7 +1374,7 @@ chtml30_start_center_tag(Chtml30* chtml30, Node* node)
  * @return The conversion result is returned.
  */
 static char*
-chtml30_end_center_tag(Chtml30* chtml30, Node* child) 
+s_chtml30_end_center_tag(chtml30_t* chtml30, Node* child) 
 {
   Doc*          doc = chtml30->doc;
   request_rec*  r   = doc->r;
@@ -1393,7 +1393,7 @@ chtml30_end_center_tag(Chtml30* chtml30, Node* child)
  * @return The conversion result is returned.
  */
 static char*
-chtml30_start_hr_tag(Chtml30* chtml30, Node* node) 
+s_chtml30_start_hr_tag(chtml30_t* chtml30, Node* node) 
 {
   Doc* doc = chtml30->doc;
   request_rec* r = doc->r;
@@ -1469,7 +1469,7 @@ chtml30_start_hr_tag(Chtml30* chtml30, Node* node)
  * @return The conversion result is returned.
  */
 static char*
-chtml30_end_hr_tag(Chtml30* chtml30, Node* child) 
+s_chtml30_end_hr_tag(chtml30_t* chtml30, Node* child) 
 {
   return chtml30->out;
 }
@@ -1483,13 +1483,13 @@ chtml30_end_hr_tag(Chtml30* chtml30, Node* child)
  * @return The conversion result is returned.
  */
 static char*
-chtml30_start_img_tag(Chtml30* chtml30, Node* node) 
+s_chtml30_start_img_tag(chtml30_t* chtml30, Node* node) 
 {
   Doc*          doc = chtml30->doc;
   request_rec*  r   = doc->r;
   Attr* attr;
 #ifndef IMG_NOT_CONVERT_FILENAME
-  device_table* spec = chtml30->spec;
+  device_table_t* spec = chtml30->spec;
 #endif
 
   chtml30->out = apr_pstrcat(r->pool, chtml30->out, "<img", NULL);
@@ -1598,7 +1598,7 @@ chtml30_start_img_tag(Chtml30* chtml30, Node* node)
  * @return The conversion result is returned.
  */
 static char*
-chtml30_end_img_tag(Chtml30* chtml30, Node* child) 
+s_chtml30_end_img_tag(chtml30_t* chtml30, Node* child) 
 {
   return chtml30->out;
 }
@@ -1612,7 +1612,7 @@ chtml30_end_img_tag(Chtml30* chtml30, Node* child)
  * @return The conversion result is returned.
  */
 static char*
-chtml30_start_select_tag(Chtml30* chtml30, Node* child)
+s_chtml30_start_select_tag(chtml30_t* chtml30, Node* child)
 {
   Doc* doc = chtml30->doc;
   request_rec* r = doc->r;
@@ -1675,7 +1675,7 @@ chtml30_start_select_tag(Chtml30* chtml30, Node* child)
  * @return The conversion result is returned.
  */
 static char*
-chtml30_end_select_tag(Chtml30* chtml30, Node* child)
+s_chtml30_end_select_tag(chtml30_t* chtml30, Node* child)
 {
   Doc* doc = chtml30->doc;
   request_rec* r = doc->r;
@@ -1693,7 +1693,7 @@ chtml30_end_select_tag(Chtml30* chtml30, Node* child)
  * @return The conversion result is returned.
  */
 static char*
-chtml30_start_option_tag(Chtml30* chtml30, Node* child)
+s_chtml30_start_option_tag(chtml30_t* chtml30, Node* child)
 {
   Doc* doc = chtml30->doc;
   request_rec* r = doc->r;
@@ -1754,7 +1754,7 @@ chtml30_start_option_tag(Chtml30* chtml30, Node* child)
  * @return The conversion result is returned.
  */
 static char*
-chtml30_end_option_tag(Chtml30* chtml30, Node* child)
+s_chtml30_end_option_tag(chtml30_t* chtml30, Node* child)
 {
   /* Don't close */
   return chtml30->out;
@@ -1769,7 +1769,7 @@ chtml30_end_option_tag(Chtml30* chtml30, Node* child)
  * @return The conversion result is returned.
  */
 static char*
-chtml30_start_div_tag(Chtml30* chtml30, Node* child)
+s_chtml30_start_div_tag(chtml30_t* chtml30, Node* child)
 {
   Doc* doc = chtml30->doc;
   request_rec* r = doc->r;
@@ -1813,7 +1813,7 @@ chtml30_start_div_tag(Chtml30* chtml30, Node* child)
  * @return The conversion result is returned.
  */
 static char*
-chtml30_end_div_tag(Chtml30* chtml30, Node* child)
+s_chtml30_end_div_tag(chtml30_t* chtml30, Node* child)
 {
   Doc* doc = chtml30->doc;
   request_rec* r = doc->r;
@@ -1825,7 +1825,7 @@ chtml30_end_div_tag(Chtml30* chtml30, Node* child)
 
 
 static void
-chtml30_chxjif_tag(Chtml30* chtml30, Node* node)
+s_chtml30_chxjif_tag(chtml30_t* chtml30, Node* node)
 {
   Doc*         doc   = chtml30->doc;
   Node*        child;
@@ -1836,7 +1836,7 @@ chtml30_chxjif_tag(Chtml30* chtml30, Node* node)
        child = qs_get_next_node(doc, child))
   {
     chtml30->out = apr_pstrcat(r->pool, chtml30->out, child->otext, NULL);
-    chtml30_chxjif_tag(chtml30, child);
+    s_chtml30_chxjif_tag(chtml30, child);
   }
 }
 /*
