@@ -26,24 +26,24 @@
 #include "chxj_str_util.h"
 
 
-static void set_devices_data(Doc* doc, apr_pool_t* p, mod_chxj_config* conf, Node* node) ;
-static void set_user_agent_data(Doc* doc, apr_pool_t* p, mod_chxj_config* conf, Node* node) ;
-static void set_device_data(Doc* doc, apr_pool_t* p, device_table_list* dtl, Node* node) ;
+static void s_set_devices_data(Doc* doc, apr_pool_t* p, mod_chxj_config_t* conf, Node* node) ;
+static void s_set_user_agent_data(Doc* doc, apr_pool_t* p, mod_chxj_config_t* conf, Node* node) ;
+static void s_set_device_data(Doc* doc, apr_pool_t* p, device_table_list_t* dtl, Node* node) ;
 /**
  * load device_data.xml
  */
 void
-chxj_load_device_data(Doc* doc, apr_pool_t *p, mod_chxj_config* conf) 
+chxj_load_device_data(Doc* doc, apr_pool_t *p, mod_chxj_config_t* conf) 
 {
   conf->devices = NULL;
-  set_devices_data(doc, p, conf,qs_get_root(doc));
+  s_set_devices_data(doc, p, conf,qs_get_root(doc));
 #if 0
   do {
     FILE* fp = fopen("/tmp/load_device.log", "a");
-    device_table_list* ll = conf->devices;
+    device_table_list_t* ll = conf->devices;
     for (;ll; ll= ll->next)
     {
-      device_table* dt;
+      device_table_t* dt;
       fprintf(fp, "user_agent:[%s]\n", ll->pattern);
       for (dt = ll->table; dt; dt = dt->next)
       {
@@ -66,7 +66,7 @@ chxj_load_device_data(Doc* doc, apr_pool_t *p, mod_chxj_config* conf)
  * <devices>
  */
 static void
-set_devices_data(Doc* doc, apr_pool_t* p, mod_chxj_config* conf, Node* node) 
+s_set_devices_data(Doc* doc, apr_pool_t* p, mod_chxj_config_t* conf, Node* node) 
 {
   Node* child;
   for (child = qs_get_child_node(doc,node); 
@@ -76,7 +76,7 @@ set_devices_data(Doc* doc, apr_pool_t* p, mod_chxj_config* conf, Node* node)
     char* name = qs_get_node_name(doc,child);
     if (strcasecmp(name, "devices") == 0) 
     {
-      set_user_agent_data(doc, p, conf, child);
+      s_set_user_agent_data(doc, p, conf, child);
     }
   }
 }
@@ -85,10 +85,10 @@ set_devices_data(Doc* doc, apr_pool_t* p, mod_chxj_config* conf, Node* node)
  * <user_agent>
  */
 static void
-set_user_agent_data(Doc* doc, apr_pool_t* p, mod_chxj_config* conf, Node* node) 
+s_set_user_agent_data(Doc* doc, apr_pool_t* p, mod_chxj_config_t* conf, Node* node) 
 {
   Node* child;
-  device_table_list* t;
+  device_table_list_t* t;
 
   for (child = qs_get_child_node(doc,node);
        child ;
@@ -99,11 +99,11 @@ set_user_agent_data(Doc* doc, apr_pool_t* p, mod_chxj_config* conf, Node* node)
     if (strcasecmp(name, "user_agent") == 0 ) 
     {
       Attr* attr;
-      device_table_list* dtl;
+      device_table_list_t* dtl;
 
       if (conf->devices == NULL) 
       {
-        conf->devices = apr_pcalloc(p, sizeof(device_table_list));
+        conf->devices = apr_pcalloc(p, sizeof(device_table_list_t));
         conf->devices->next    = NULL;
         conf->devices->pattern = NULL;
         conf->devices->table   = NULL;
@@ -119,7 +119,7 @@ set_user_agent_data(Doc* doc, apr_pool_t* p, mod_chxj_config* conf, Node* node)
             break;
           }
         }
-        t->next = apr_pcalloc(p, sizeof(device_table_list));
+        t->next = apr_pcalloc(p, sizeof(device_table_list_t));
         t->next->next = NULL;
         t->next->pattern = NULL;
         t->next->table = NULL;
@@ -134,18 +134,18 @@ set_user_agent_data(Doc* doc, apr_pool_t* p, mod_chxj_config* conf, Node* node)
             dtl->pattern = apr_pstrdup(p, qs_get_attr_value(doc,attr));
         }
       }
-      set_device_data(doc, p, dtl, child);
+      s_set_device_data(doc, p, dtl, child);
     }
   }
 }
 
 static void
-set_device_data(Doc* doc, apr_pool_t* p, device_table_list* dtl, Node* node) 
+s_set_device_data(Doc* doc, apr_pool_t* p, device_table_list_t* dtl, Node* node) 
 {
   Node* child;
-  device_table* dt;
+  device_table_t* dt;
 
-  dt = apr_pcalloc(p, sizeof(device_table));
+  dt = apr_pcalloc(p, sizeof(device_table_t));
   dt->next           = NULL;
   dt->device_id      = NULL;
   dt->device_name    = NULL;
@@ -167,7 +167,7 @@ set_device_data(Doc* doc, apr_pool_t* p, device_table_list* dtl, Node* node)
     char* name = qs_get_node_name(doc,child);
     if (strcasecmp(name, "device") == 0) 
     {
-      set_device_data(doc,p, dtl, child);
+      s_set_device_data(doc,p, dtl, child);
     }
     else
     if (strcasecmp(name, "device_id") == 0) 
