@@ -18,6 +18,6 @@
 #define __LOAD_DEVICE_DATA_H__
 #include "mod_chxj.h"
 
-void chxj_load_device_data(Doc* doc, apr_pool_t *p, mod_chxj_config* conf);
+void chxj_load_device_data(Doc* doc, apr_pool_t *p, mod_chxj_config_t* conf);
 
 #endif
