@@ -22,44 +22,44 @@
 #include "chxj_qr_code.h"
 
 
-static char* xhtml_1_0_node_exchange    (Xhtml* xhtml, Node* node, int indent);
-static char* xhtml_1_0_start_html_tag   (Xhtml* xhtml, Node* child);
-static char* xhtml_1_0_end_html_tag     (Xhtml* xhtml, Node* child);
-static char* xhtml_1_0_start_meta_tag   (Xhtml* xhtml, Node* node);
-static char* xhtml_1_0_end_meta_tag     (Xhtml* xhtml, Node* node);
-static char* xhtml_1_0_start_head_tag   (Xhtml* xhtml, Node* node);
-static char* xhtml_1_0_end_head_tag     (Xhtml* xhtml, Node* node);
-static char* xhtml_1_0_start_title_tag  (Xhtml* xhtml, Node* node);
-static char* xhtml_1_0_end_title_tag    (Xhtml* xhtml, Node* node);
-static char* xhtml_1_0_start_base_tag   (Xhtml* xhtml, Node* node);
-static char* xhtml_1_0_end_base_tag     (Xhtml* xhtml, Node* node);
-static char* xhtml_1_0_start_body_tag   (Xhtml* xhtml, Node* node);
-static char* xhtml_1_0_end_body_tag     (Xhtml* xhtml, Node* node);
-static char* xhtml_1_0_start_a_tag      (Xhtml* xhtml, Node* node);
-static char* xhtml_1_0_end_a_tag        (Xhtml* xhtml, Node* node);
-static char* xhtml_1_0_start_br_tag     (Xhtml* xhtml, Node* node);
-static char* xhtml_1_0_end_br_tag       (Xhtml* xhtml, Node* node);
-static char* xhtml_1_0_start_font_tag   (Xhtml* xhtml, Node* node);
-static char* xhtml_1_0_end_font_tag     (Xhtml* xhtml, Node* node);
-static char* xhtml_1_0_start_form_tag   (Xhtml* xhtml, Node* node);
-static char* xhtml_1_0_end_form_tag     (Xhtml* xhtml, Node* node);
-static char* xhtml_1_0_start_input_tag  (Xhtml* xhtml, Node* node);
-static char* xhtml_1_0_end_input_tag    (Xhtml* xhtml, Node* node);
-static char* xhtml_1_0_start_center_tag (Xhtml* xhtml, Node* node);
-static char* xhtml_1_0_end_center_tag   (Xhtml* xhtml, Node* node);
-static char* xhtml_1_0_start_hr_tag     (Xhtml* xhtml, Node* node);
-static char* xhtml_1_0_end_hr_tag       (Xhtml* xhtml, Node* node);
-static char* xhtml_1_0_start_img_tag    (Xhtml* xhtml, Node* node);
-static char* xhtml_1_0_end_img_tag      (Xhtml* xhtml, Node* node);
-static char* xhtml_1_0_start_select_tag (Xhtml* xhtml, Node* node);
-static char* xhtml_1_0_end_select_tag   (Xhtml* xhtml, Node* node);
-static char* xhtml_1_0_start_option_tag (Xhtml* xhtml, Node* node);
-static char* xhtml_1_0_end_option_tag   (Xhtml* xhtml, Node* node);
-static char* xhtml_1_0_start_div_tag    (Xhtml* xhtml, Node* node);
-static char* xhtml_1_0_end_div_tag      (Xhtml* xhtml, Node* node);
-static void chxj_init_xhtml(Xhtml* xhtml, Doc* doc, request_rec* r, device_table* spec);
-static int xhtml_search_emoji(Xhtml* xhtml, char* txt, char** rslt);
-static void xhtml_1_0_chxjif_tag(Xhtml* xhtml, Node* node);
+static char* s_xhtml_1_0_node_exchange    (xhtml_t* xhtml, Node* node, int indent);
+static char* s_xhtml_1_0_start_html_tag   (xhtml_t* xhtml, Node* child);
+static char* s_xhtml_1_0_end_html_tag     (xhtml_t* xhtml, Node* child);
+static char* s_xhtml_1_0_start_meta_tag   (xhtml_t* xhtml, Node* node);
+static char* s_xhtml_1_0_end_meta_tag     (xhtml_t* xhtml, Node* node);
+static char* s_xhtml_1_0_start_head_tag   (xhtml_t* xhtml, Node* node);
+static char* s_xhtml_1_0_end_head_tag     (xhtml_t* xhtml, Node* node);
+static char* s_xhtml_1_0_start_title_tag  (xhtml_t* xhtml, Node* node);
+static char* s_xhtml_1_0_end_title_tag    (xhtml_t* xhtml, Node* node);
+static char* s_xhtml_1_0_start_base_tag   (xhtml_t* xhtml, Node* node);
+static char* s_xhtml_1_0_end_base_tag     (xhtml_t* xhtml, Node* node);
+static char* s_xhtml_1_0_start_body_tag   (xhtml_t* xhtml, Node* node);
+static char* s_xhtml_1_0_end_body_tag     (xhtml_t* xhtml, Node* node);
+static char* s_xhtml_1_0_start_a_tag      (xhtml_t* xhtml, Node* node);
+static char* s_xhtml_1_0_end_a_tag        (xhtml_t* xhtml, Node* node);
+static char* s_xhtml_1_0_start_br_tag     (xhtml_t* xhtml, Node* node);
+static char* s_xhtml_1_0_end_br_tag       (xhtml_t* xhtml, Node* node);
+static char* s_xhtml_1_0_start_font_tag   (xhtml_t* xhtml, Node* node);
+static char* s_xhtml_1_0_end_font_tag     (xhtml_t* xhtml, Node* node);
+static char* s_xhtml_1_0_start_form_tag   (xhtml_t* xhtml, Node* node);
+static char* s_xhtml_1_0_end_form_tag     (xhtml_t* xhtml, Node* node);
+static char* s_xhtml_1_0_start_input_tag  (xhtml_t* xhtml, Node* node);
+static char* s_xhtml_1_0_end_input_tag    (xhtml_t* xhtml, Node* node);
+static char* s_xhtml_1_0_start_center_tag (xhtml_t* xhtml, Node* node);
+static char* s_xhtml_1_0_end_center_tag   (xhtml_t* xhtml, Node* node);
+static char* s_xhtml_1_0_start_hr_tag     (xhtml_t* xhtml, Node* node);
+static char* s_xhtml_1_0_end_hr_tag       (xhtml_t* xhtml, Node* node);
+static char* s_xhtml_1_0_start_img_tag    (xhtml_t* xhtml, Node* node);
+static char* s_xhtml_1_0_end_img_tag      (xhtml_t* xhtml, Node* node);
+static char* s_xhtml_1_0_start_select_tag (xhtml_t* xhtml, Node* node);
+static char* s_xhtml_1_0_end_select_tag   (xhtml_t* xhtml, Node* node);
+static char* s_xhtml_1_0_start_option_tag (xhtml_t* xhtml, Node* node);
+static char* s_xhtml_1_0_end_option_tag   (xhtml_t* xhtml, Node* node);
+static char* s_xhtml_1_0_start_div_tag    (xhtml_t* xhtml, Node* node);
+static char* s_xhtml_1_0_end_div_tag      (xhtml_t* xhtml, Node* node);
+static void  s_init_xhtml(xhtml_t* xhtml, Doc* doc, request_rec* r, device_table_t* spec);
+static int   s_xhtml_search_emoji(xhtml_t* xhtml, char* txt, char** rslt);
+static void  s_xhtml_1_0_chxjif_tag(xhtml_t* xhtml, Node* node);
  
 /**
  * converts from CHTML to XHTML.
@@ -73,14 +73,14 @@ static void xhtml_1_0_chxjif_tag(Xhtml* xhtml, Node* node);
 char*
 chxj_exchange_xhtml_mobile_1_0(
   request_rec* r,
-  device_table *spec,
+  device_table_t* spec,
   const char* src,
   apr_size_t srclen,
   apr_size_t *dstlen)
 {
   char*     dst = NULL;
   char*     ss;
-  Xhtml     xhtml;
+  xhtml_t     xhtml;
   Doc       doc;
 
   ap_log_rerror(APLOG_MARK, APLOG_DEBUG, 0, r,"start chxj_exchange_xhtml_mobile_1_0()");
@@ -100,7 +100,7 @@ chxj_exchange_xhtml_mobile_1_0(
   /*--------------------------------------------------------------------------*/
   /* The XHTML structure is initialized.                                      */
   /*--------------------------------------------------------------------------*/
-  chxj_init_xhtml(&xhtml, &doc, r, spec);
+  s_init_xhtml(&xhtml, &doc, r, spec);
   ap_set_content_type(r, "text/html; charset=Windows-31J");
 
   /*--------------------------------------------------------------------------*/
@@ -123,7 +123,7 @@ chxj_exchange_xhtml_mobile_1_0(
   /*--------------------------------------------------------------------------*/
   /* It converts it from CHTML to XHTML.                                      */
   /*--------------------------------------------------------------------------*/
-  dst = xhtml_1_0_node_exchange(&xhtml, qs_get_root(&doc), 0);
+  dst = s_xhtml_1_0_node_exchange(&xhtml, qs_get_root(&doc), 0);
   qs_all_free(&doc,QX_LOGMARK);
 
   if (dst == NULL) 
@@ -154,10 +154,10 @@ chxj_exchange_xhtml_mobile_1_0(
  * @param spec  [i]   The pointer to the device_table
  */
 static void
-chxj_init_xhtml(Xhtml* xhtml, Doc* doc, request_rec* r, device_table* spec)
+s_init_xhtml(xhtml_t* xhtml, Doc* doc, request_rec* r, device_table_t* spec)
 {
   memset(doc,   0, sizeof(Doc));
-  memset(xhtml, 0, sizeof(Xhtml));
+  memset(xhtml, 0, sizeof(xhtml_t));
 
   doc->r      = r;
   xhtml->doc  = doc;
@@ -177,7 +177,7 @@ chxj_init_xhtml(Xhtml* xhtml, Doc* doc, request_rec* r, device_table* spec)
  * @return The character string after it converts it is returned. 
  */
 static char*
-xhtml_1_0_node_exchange(Xhtml* xhtml, Node* node, int indent) 
+s_xhtml_1_0_node_exchange(xhtml_t* xhtml, Node* node, int indent) 
 {
   Node*         child;
   Doc*          doc   = xhtml->doc;
@@ -197,9 +197,9 @@ xhtml_1_0_node_exchange(Xhtml* xhtml, Node* node, int indent)
     /*------------------------------------------------------------------------*/
     if (strcasecmp(name, "html") == 0) 
     {
-      xhtml_1_0_start_html_tag(xhtml, child);
-      xhtml_1_0_node_exchange (xhtml, child,indent+1);
-      xhtml_1_0_end_html_tag  (xhtml, child);
+      s_xhtml_1_0_start_html_tag(xhtml, child);
+      s_xhtml_1_0_node_exchange (xhtml, child,indent+1);
+      s_xhtml_1_0_end_html_tag  (xhtml, child);
     }
     /*------------------------------------------------------------------------*/
     /* <META>                                                                 */
@@ -207,8 +207,8 @@ xhtml_1_0_node_exchange(Xhtml* xhtml, Node* node, int indent)
     else
     if (strcasecmp(name, "meta") == 0) 
     {
-      xhtml_1_0_start_meta_tag(xhtml, child);
-      xhtml_1_0_end_meta_tag  (xhtml, child);
+      s_xhtml_1_0_start_meta_tag(xhtml, child);
+      s_xhtml_1_0_end_meta_tag  (xhtml, child);
     }
     /*------------------------------------------------------------------------*/
     /* <HEAD>                                                                 */
@@ -216,9 +216,9 @@ xhtml_1_0_node_exchange(Xhtml* xhtml, Node* node, int indent)
     else
     if (strcasecmp(name, "head") == 0) 
     {
-      xhtml_1_0_start_head_tag(xhtml, child);
-      xhtml_1_0_node_exchange (xhtml, child,indent+1);
-      xhtml_1_0_end_head_tag  (xhtml, child);
+      s_xhtml_1_0_start_head_tag(xhtml, child);
+      s_xhtml_1_0_node_exchange (xhtml, child,indent+1);
+      s_xhtml_1_0_end_head_tag  (xhtml, child);
     }
     /*------------------------------------------------------------------------*/
     /* <TITLE>                                                                */
@@ -226,9 +226,9 @@ xhtml_1_0_node_exchange(Xhtml* xhtml, Node* node, int indent)
     else
     if (strcasecmp(name, "title") == 0) 
     {
-      xhtml_1_0_start_title_tag (xhtml, child);
-      xhtml_1_0_node_exchange   (xhtml, child,indent+1);
-      xhtml_1_0_end_title_tag   (xhtml, child);
+      s_xhtml_1_0_start_title_tag (xhtml, child);
+      s_xhtml_1_0_node_exchange   (xhtml, child,indent+1);
+      s_xhtml_1_0_end_title_tag   (xhtml, child);
     }
     /*------------------------------------------------------------------------*/
     /* <BASE>                                                                 */
@@ -236,8 +236,8 @@ xhtml_1_0_node_exchange(Xhtml* xhtml, Node* node, int indent)
     else
     if (strcasecmp(name, "base") == 0) 
     {
-      xhtml_1_0_start_base_tag(xhtml, child);
-      xhtml_1_0_end_base_tag  (xhtml, child);
+      s_xhtml_1_0_start_base_tag(xhtml, child);
+      s_xhtml_1_0_end_base_tag  (xhtml, child);
     }
     /*------------------------------------------------------------------------*/
     /* <BODY>                                                                 */
@@ -245,9 +245,9 @@ xhtml_1_0_node_exchange(Xhtml* xhtml, Node* node, int indent)
     else
     if (strcasecmp(name, "body") == 0) 
     {
-      xhtml_1_0_start_body_tag(xhtml, child);
-      xhtml_1_0_node_exchange (xhtml, child,indent+1);
-      xhtml_1_0_end_body_tag  (xhtml, child);
+      s_xhtml_1_0_start_body_tag(xhtml, child);
+      s_xhtml_1_0_node_exchange (xhtml, child,indent+1);
+      s_xhtml_1_0_end_body_tag  (xhtml, child);
     }
     /*------------------------------------------------------------------------*/
     /* <A>                                                                    */
@@ -255,9 +255,9 @@ xhtml_1_0_node_exchange(Xhtml* xhtml, Node* node, int indent)
     else
     if (strcasecmp(name, "a") == 0) 
     {
-      xhtml_1_0_start_a_tag   (xhtml, child);
-      xhtml_1_0_node_exchange (xhtml, child,indent+1);
-      xhtml_1_0_end_a_tag     (xhtml, child);
+      s_xhtml_1_0_start_a_tag   (xhtml, child);
+      s_xhtml_1_0_node_exchange (xhtml, child,indent+1);
+      s_xhtml_1_0_end_a_tag     (xhtml, child);
     }
     /*------------------------------------------------------------------------*/
     /* <BR>                                                                   */
@@ -265,9 +265,9 @@ xhtml_1_0_node_exchange(Xhtml* xhtml, Node* node, int indent)
     else
     if (strcasecmp(name, "br") == 0) 
     {
-      xhtml_1_0_start_br_tag  (xhtml, child);
-      xhtml_1_0_node_exchange (xhtml, child,indent+1);
-      xhtml_1_0_end_br_tag    (xhtml, child);
+      s_xhtml_1_0_start_br_tag  (xhtml, child);
+      s_xhtml_1_0_node_exchange (xhtml, child,indent+1);
+      s_xhtml_1_0_end_br_tag    (xhtml, child);
     }
     /*------------------------------------------------------------------------*/
     /* <FONT>                                                                 */
@@ -275,9 +275,9 @@ xhtml_1_0_node_exchange(Xhtml* xhtml, Node* node, int indent)
     else
     if (strcasecmp(name, "font") == 0) 
     {
-      xhtml_1_0_start_font_tag(xhtml, child);
-      xhtml_1_0_node_exchange (xhtml, child,indent+1);
-      xhtml_1_0_end_font_tag  (xhtml, child);
+      s_xhtml_1_0_start_font_tag(xhtml, child);
+      s_xhtml_1_0_node_exchange (xhtml, child,indent+1);
+      s_xhtml_1_0_end_font_tag  (xhtml, child);
     }
     /*------------------------------------------------------------------------*/
     /* <FORM>                                                                 */
@@ -285,9 +285,9 @@ xhtml_1_0_node_exchange(Xhtml* xhtml, Node* node, int indent)
     else
     if (strcasecmp(name, "form") == 0) 
     {
-      xhtml_1_0_start_form_tag(xhtml, child);
-      xhtml_1_0_node_exchange (xhtml, child,indent+1);
-      xhtml_1_0_end_form_tag  (xhtml, child);
+      s_xhtml_1_0_start_form_tag(xhtml, child);
+      s_xhtml_1_0_node_exchange (xhtml, child,indent+1);
+      s_xhtml_1_0_end_form_tag  (xhtml, child);
     }
     /*------------------------------------------------------------------------*/
     /* <INPUT>                                                                */
@@ -295,9 +295,9 @@ xhtml_1_0_node_exchange(Xhtml* xhtml, Node* node, int indent)
     else
     if (strcasecmp(name, "input") == 0) 
     {
-      xhtml_1_0_start_input_tag (xhtml, child);
-      xhtml_1_0_node_exchange   (xhtml, child,indent+1);
-      xhtml_1_0_end_input_tag   (xhtml, child);
+      s_xhtml_1_0_start_input_tag (xhtml, child);
+      s_xhtml_1_0_node_exchange   (xhtml, child,indent+1);
+      s_xhtml_1_0_end_input_tag   (xhtml, child);
     }
     /*------------------------------------------------------------------------*/
     /* <HR>                                                                   */
@@ -305,8 +305,8 @@ xhtml_1_0_node_exchange(Xhtml* xhtml, Node* node, int indent)
     else
     if (strcasecmp(name, "hr") == 0) 
     {
-      xhtml_1_0_start_hr_tag  (xhtml, child);
-      xhtml_1_0_end_hr_tag    (xhtml, child);
+      s_xhtml_1_0_start_hr_tag  (xhtml, child);
+      s_xhtml_1_0_end_hr_tag    (xhtml, child);
     }
     /*------------------------------------------------------------------------*/
     /* <CENTER>                                                               */
@@ -314,9 +314,9 @@ xhtml_1_0_node_exchange(Xhtml* xhtml, Node* node, int indent)
     else
     if (strcasecmp(name, "center") == 0) 
     {
-      xhtml_1_0_start_center_tag(xhtml, child);
-      xhtml_1_0_node_exchange   (xhtml, child,indent+1);
-      xhtml_1_0_end_center_tag  (xhtml, child);
+      s_xhtml_1_0_start_center_tag(xhtml, child);
+      s_xhtml_1_0_node_exchange   (xhtml, child,indent+1);
+      s_xhtml_1_0_end_center_tag  (xhtml, child);
     }
     /*------------------------------------------------------------------------*/
     /* <IMG>                                                                  */
@@ -324,8 +324,8 @@ xhtml_1_0_node_exchange(Xhtml* xhtml, Node* node, int indent)
     else
     if (strcasecmp(name, "img") == 0) 
     {
-      xhtml_1_0_start_img_tag (xhtml, child);
-      xhtml_1_0_end_img_tag   (xhtml, child);
+      s_xhtml_1_0_start_img_tag (xhtml, child);
+      s_xhtml_1_0_end_img_tag   (xhtml, child);
     }
     /*------------------------------------------------------------------------*/
     /* <SELECT>                                                               */
@@ -333,9 +333,9 @@ xhtml_1_0_node_exchange(Xhtml* xhtml, Node* node, int indent)
     else
     if (strcasecmp(name, "select") == 0)
     {
-      xhtml_1_0_start_select_tag(xhtml, child);
-      xhtml_1_0_node_exchange   (xhtml, child, indent+1);
-      xhtml_1_0_end_select_tag  (xhtml, child);
+      s_xhtml_1_0_start_select_tag(xhtml, child);
+      s_xhtml_1_0_node_exchange   (xhtml, child, indent+1);
+      s_xhtml_1_0_end_select_tag  (xhtml, child);
     }
     /*------------------------------------------------------------------------*/
     /* <OPTION>                                                               */
@@ -343,9 +343,9 @@ xhtml_1_0_node_exchange(Xhtml* xhtml, Node* node, int indent)
     else
     if (strcasecmp(name, "option") == 0)
     {
-      xhtml_1_0_start_option_tag(xhtml, child);
-      xhtml_1_0_node_exchange   (xhtml, child, indent+1);
-      xhtml_1_0_end_option_tag  (xhtml, child);
+      s_xhtml_1_0_start_option_tag(xhtml, child);
+      s_xhtml_1_0_node_exchange   (xhtml, child, indent+1);
+      s_xhtml_1_0_end_option_tag  (xhtml, child);
     }
     /*------------------------------------------------------------------------*/
     /* <DIV>                                                                  */
@@ -353,9 +353,9 @@ xhtml_1_0_node_exchange(Xhtml* xhtml, Node* node, int indent)
     else
     if (strcasecmp(name, "div") == 0)
     {
-      xhtml_1_0_start_div_tag (xhtml, child);
-      xhtml_1_0_node_exchange (xhtml, child, indent+1);
-      xhtml_1_0_end_div_tag   (xhtml, child);
+      s_xhtml_1_0_start_div_tag (xhtml, child);
+      s_xhtml_1_0_node_exchange (xhtml, child, indent+1);
+      s_xhtml_1_0_end_div_tag   (xhtml, child);
     }
     /*------------------------------------------------------------------------*/
     /* <CHXJ:IF>                                                              */
@@ -377,11 +377,11 @@ xhtml_1_0_node_exchange(Xhtml* xhtml, Node* node, int indent)
         parse_attr = qs_get_parse_attr(doc, child, r);
         if (parse_attr != NULL && strcasecmp(parse_attr, "true") == 0)
         {
-          xhtml_1_0_node_exchange (xhtml, child, indent+1);
+          s_xhtml_1_0_node_exchange (xhtml, child, indent+1);
         }
         else
         {
-          xhtml_1_0_chxjif_tag(xhtml, child);
+          s_xhtml_1_0_chxjif_tag(xhtml, child);
         }
       }
     }
@@ -415,7 +415,7 @@ xhtml_1_0_node_exchange(Xhtml* xhtml, Node* node, int indent)
       for (ii=0; ii<qs_get_node_size(doc,child); ii++)
       {
         char* out;
-        int rtn = xhtml_search_emoji(xhtml, &textval[ii], &out);
+        int rtn = s_xhtml_search_emoji(xhtml, &textval[ii], &out);
         if (rtn != 0)
         {
           ap_log_rerror(APLOG_MARK, APLOG_DEBUG,0, r,
@@ -456,11 +456,11 @@ xhtml_1_0_node_exchange(Xhtml* xhtml, Node* node, int indent)
  * @return When corresponding EMOJI exists, it returns it excluding 0. 
  */
 static int
-xhtml_search_emoji(Xhtml* xhtml, char* txt, char** rslt)
+s_xhtml_search_emoji(xhtml_t* xhtml, char* txt, char** rslt)
 {
   emoji_t*      ee;
   request_rec*  r;
-  device_table* spec;
+  device_table_t* spec;
   int           len;
 
   spec = xhtml->spec;
@@ -605,7 +605,7 @@ xhtml_search_emoji(Xhtml* xhtml, char* txt, char** rslt)
  * @return The conversion result is returned.
  */
 static char*
-xhtml_1_0_start_html_tag(Xhtml* xhtml, Node* node) 
+s_xhtml_1_0_start_html_tag(xhtml_t* xhtml, Node* node) 
 {
   Attr*         attr;
   Doc*          doc   = xhtml->doc;
@@ -677,7 +677,7 @@ xhtml_1_0_start_html_tag(Xhtml* xhtml, Node* node)
  * @return The conversion result is returned.
  */
 static char*
-xhtml_1_0_end_html_tag(Xhtml* xhtml, Node* child) 
+s_xhtml_1_0_end_html_tag(xhtml_t* xhtml, Node* child) 
 {
   Doc*          doc = xhtml->doc;
   request_rec*  r   = doc->r;
@@ -696,7 +696,7 @@ xhtml_1_0_end_html_tag(Xhtml* xhtml, Node* child)
  * @return The conversion result is returned.
  */
 static char*
-xhtml_1_0_start_meta_tag(Xhtml* xhtml, Node* node) 
+s_xhtml_1_0_start_meta_tag(xhtml_t* xhtml, Node* node) 
 {
   Attr*         attr;
   Doc*          doc   = xhtml->doc;
@@ -767,7 +767,7 @@ xhtml_1_0_start_meta_tag(Xhtml* xhtml, Node* node)
  * @return The conversion result is returned.
  */
 static char*
-xhtml_1_0_end_meta_tag(Xhtml* xhtml, Node* child) 
+s_xhtml_1_0_end_meta_tag(xhtml_t* xhtml, Node* child) 
 {
   return xhtml->out;
 }
@@ -781,7 +781,7 @@ xhtml_1_0_end_meta_tag(Xhtml* xhtml, Node* child)
  * @return The conversion result is returned.
  */
 static char*
-xhtml_1_0_start_head_tag(Xhtml* xhtml, Node* node) 
+s_xhtml_1_0_start_head_tag(xhtml_t* xhtml, Node* node) 
 {
   Doc*          doc = xhtml->doc;
   request_rec*  r   = doc->r;
@@ -799,7 +799,7 @@ xhtml_1_0_start_head_tag(Xhtml* xhtml, Node* node)
  * @return The conversion result is returned.
  */
 static char*
-xhtml_1_0_end_head_tag(Xhtml* xhtml, Node* child) 
+s_xhtml_1_0_end_head_tag(xhtml_t* xhtml, Node* child) 
 {
   Doc*          doc = xhtml->doc;
   request_rec*  r   = doc->r;
@@ -817,7 +817,7 @@ xhtml_1_0_end_head_tag(Xhtml* xhtml, Node* child)
  * @return The conversion result is returned.
  */
 static char*
-xhtml_1_0_start_title_tag(Xhtml* xhtml, Node* node) 
+s_xhtml_1_0_start_title_tag(xhtml_t* xhtml, Node* node) 
 {
   Doc* doc = xhtml->doc;
   request_rec* r = doc->r;
@@ -835,7 +835,7 @@ xhtml_1_0_start_title_tag(Xhtml* xhtml, Node* node)
  * @return The conversion result is returned.
  */
 static char*
-xhtml_1_0_end_title_tag(Xhtml* xhtml, Node* child) 
+s_xhtml_1_0_end_title_tag(xhtml_t* xhtml, Node* child) 
 {
   Doc*          doc = xhtml->doc;
   request_rec*  r   = doc->r;
@@ -854,7 +854,7 @@ xhtml_1_0_end_title_tag(Xhtml* xhtml, Node* child)
  * @return The conversion result is returned.
  */
 static char*
-xhtml_1_0_start_base_tag(Xhtml* xhtml, Node* node) 
+s_xhtml_1_0_start_base_tag(xhtml_t* xhtml, Node* node) 
 {
   Attr*         attr;
   Doc*          doc   = xhtml->doc;
@@ -894,7 +894,7 @@ xhtml_1_0_start_base_tag(Xhtml* xhtml, Node* node)
  * @return The conversion result is returned.
  */
 static char*
-xhtml_1_0_end_base_tag(Xhtml* xhtml, Node* child) 
+s_xhtml_1_0_end_base_tag(xhtml_t* xhtml, Node* child) 
 {
   return xhtml->out;
 }
@@ -908,7 +908,7 @@ xhtml_1_0_end_base_tag(Xhtml* xhtml, Node* child)
  * @return The conversion result is returned.
  */
 static char*
-xhtml_1_0_start_body_tag(Xhtml* xhtml, Node* node) 
+s_xhtml_1_0_start_body_tag(xhtml_t* xhtml, Node* node) 
 {
   Doc* doc = xhtml->doc;
   request_rec* r = doc->r;
@@ -978,7 +978,7 @@ xhtml_1_0_start_body_tag(Xhtml* xhtml, Node* node)
  * @return The conversion result is returned.
  */
 static char*
-xhtml_1_0_end_body_tag(Xhtml* xhtml, Node* child) 
+s_xhtml_1_0_end_body_tag(xhtml_t* xhtml, Node* child) 
 {
   Doc*          doc = xhtml->doc;
   request_rec*  r = doc->r;
@@ -997,7 +997,7 @@ xhtml_1_0_end_body_tag(Xhtml* xhtml, Node* child)
  * @return The conversion result is returned.
  */
 static char*
-xhtml_1_0_start_a_tag(Xhtml* xhtml, Node* node) 
+s_xhtml_1_0_start_a_tag(xhtml_t* xhtml, Node* node) 
 {
   Doc*          doc   = xhtml->doc;
   request_rec*  r     = doc->r;
@@ -1108,7 +1108,7 @@ xhtml_1_0_start_a_tag(Xhtml* xhtml, Node* node)
  * @return The conversion result is returned.
  */
 static char*
-xhtml_1_0_end_a_tag(Xhtml* xhtml, Node* child) 
+s_xhtml_1_0_end_a_tag(xhtml_t* xhtml, Node* child) 
 {
   Doc* doc = xhtml->doc;
   request_rec* r = doc->r;
@@ -1126,7 +1126,7 @@ xhtml_1_0_end_a_tag(Xhtml* xhtml, Node* child)
  * @return The conversion result is returned.
  */
 static char*
-xhtml_1_0_start_br_tag(Xhtml* xhtml, Node* node) 
+s_xhtml_1_0_start_br_tag(xhtml_t* xhtml, Node* node) 
 {
   Doc* doc = xhtml->doc;
   request_rec* r = doc->r;
@@ -1143,7 +1143,7 @@ xhtml_1_0_start_br_tag(Xhtml* xhtml, Node* node)
  * @return The conversion result is returned.
  */
 static char*
-xhtml_1_0_end_br_tag(Xhtml* xhtml, Node* child) 
+s_xhtml_1_0_end_br_tag(xhtml_t* xhtml, Node* child) 
 {
   return xhtml->out;
 }
@@ -1157,7 +1157,7 @@ xhtml_1_0_end_br_tag(Xhtml* xhtml, Node* child)
  * @return The conversion result is returned.
  */
 static char*
-xhtml_1_0_start_font_tag(Xhtml* xhtml, Node* node) 
+s_xhtml_1_0_start_font_tag(xhtml_t* xhtml, Node* node) 
 {
   Doc* doc = xhtml->doc;
   request_rec* r = doc->r;
@@ -1193,7 +1193,7 @@ xhtml_1_0_start_font_tag(Xhtml* xhtml, Node* node)
  * @return The conversion result is returned.
  */
 static char*
-xhtml_1_0_end_font_tag(Xhtml* xhtml, Node* child) 
+s_xhtml_1_0_end_font_tag(xhtml_t* xhtml, Node* child) 
 {
   Doc* doc = xhtml->doc;
   request_rec* r = doc->r;
@@ -1210,7 +1210,7 @@ xhtml_1_0_end_font_tag(Xhtml* xhtml, Node* child)
  * @return The conversion result is returned.
  */
 static char*
-xhtml_1_0_start_form_tag(Xhtml* xhtml, Node* node) 
+s_xhtml_1_0_start_form_tag(xhtml_t* xhtml, Node* node) 
 {
   Doc* doc = xhtml->doc;
   request_rec* r = doc->r;
@@ -1265,7 +1265,7 @@ xhtml_1_0_start_form_tag(Xhtml* xhtml, Node* node)
  * @return The conversion result is returned.
  */
 static char*
-xhtml_1_0_end_form_tag(Xhtml* xhtml, Node* child) 
+s_xhtml_1_0_end_form_tag(xhtml_t* xhtml, Node* child) 
 {
   Doc* doc = xhtml->doc;
   request_rec* r = doc->r;
@@ -1283,7 +1283,7 @@ xhtml_1_0_end_form_tag(Xhtml* xhtml, Node* child)
  * @return The conversion result is returned.
  */
 static char*
-xhtml_1_0_start_input_tag(Xhtml* xhtml, Node* node) 
+s_xhtml_1_0_start_input_tag(xhtml_t* xhtml, Node* node) 
 {
   Doc*          doc         = xhtml->doc;
   request_rec*  r           = doc->r;
@@ -1429,7 +1429,7 @@ xhtml_1_0_start_input_tag(Xhtml* xhtml, Node* node)
  * @return The conversion result is returned.
  */
 static char*
-xhtml_1_0_end_input_tag(Xhtml* xhtml, Node* child) 
+s_xhtml_1_0_end_input_tag(xhtml_t* xhtml, Node* child) 
 {
   return xhtml->out;
 }
@@ -1443,7 +1443,7 @@ xhtml_1_0_end_input_tag(Xhtml* xhtml, Node* child)
  * @return The conversion result is returned.
  */
 static char*
-xhtml_1_0_start_center_tag(Xhtml* xhtml, Node* node) 
+s_xhtml_1_0_start_center_tag(xhtml_t* xhtml, Node* node) 
 {
   Doc*          doc = xhtml->doc;
   request_rec*  r   = doc->r;
@@ -1462,7 +1462,7 @@ xhtml_1_0_start_center_tag(Xhtml* xhtml, Node* node)
  * @return The conversion result is returned.
  */
 static char*
-xhtml_1_0_end_center_tag(Xhtml* xhtml, Node* child) 
+s_xhtml_1_0_end_center_tag(xhtml_t* xhtml, Node* child) 
 {
   Doc*          doc = xhtml->doc;
   request_rec*  r   = doc->r;
@@ -1481,7 +1481,7 @@ xhtml_1_0_end_center_tag(Xhtml* xhtml, Node* child)
  * @return The conversion result is returned.
  */
 static char*
-xhtml_1_0_start_hr_tag(Xhtml* xhtml, Node* node) 
+s_xhtml_1_0_start_hr_tag(xhtml_t* xhtml, Node* node) 
 {
   Doc*          doc = xhtml->doc;
   request_rec*  r   = doc->r;
@@ -1500,7 +1500,7 @@ xhtml_1_0_start_hr_tag(Xhtml* xhtml, Node* node)
  * @return The conversion result is returned.
  */
 static char*
-xhtml_1_0_end_hr_tag(Xhtml* xhtml, Node* child) 
+s_xhtml_1_0_end_hr_tag(xhtml_t* xhtml, Node* child) 
 {
   return xhtml->out;
 }
@@ -1514,14 +1514,14 @@ xhtml_1_0_end_hr_tag(Xhtml* xhtml, Node* child)
  * @return The conversion result is returned.
  */
 static char*
-xhtml_1_0_start_img_tag(Xhtml* xhtml, Node* node) 
+s_xhtml_1_0_start_img_tag(xhtml_t* xhtml, Node* node) 
 {
   Doc*          doc = xhtml->doc;
   request_rec*  r   = doc->r;
   Attr* attr;
 
 #ifndef IMG_NOT_CONVERT_FILENAME
-  device_table* spec = xhtml->spec;
+  device_table_t* spec = xhtml->spec;
 #endif
 
   xhtml->out = apr_pstrcat(r->pool, xhtml->out, "<img", NULL);
@@ -1599,7 +1599,7 @@ xhtml_1_0_start_img_tag(Xhtml* xhtml, Node* node)
  * @return The conversion result is returned.
  */
 static char*
-xhtml_1_0_end_img_tag(Xhtml* xhtml, Node* child) 
+s_xhtml_1_0_end_img_tag(xhtml_t* xhtml, Node* child) 
 {
   return xhtml->out;
 }
@@ -1613,7 +1613,7 @@ xhtml_1_0_end_img_tag(Xhtml* xhtml, Node* child)
  * @return The conversion result is returned.
  */
 static char*
-xhtml_1_0_start_select_tag(Xhtml* xhtml, Node* child)
+s_xhtml_1_0_start_select_tag(xhtml_t* xhtml, Node* child)
 {
   Doc* doc = xhtml->doc;
   request_rec* r = doc->r;
@@ -1670,7 +1670,7 @@ xhtml_1_0_start_select_tag(Xhtml* xhtml, Node* child)
  * @return The conversion result is returned.
  */
 static char*
-xhtml_1_0_end_select_tag(Xhtml* xhtml, Node* child)
+s_xhtml_1_0_end_select_tag(xhtml_t* xhtml, Node* child)
 {
   Doc* doc = xhtml->doc;
   request_rec* r = doc->r;
@@ -1688,7 +1688,7 @@ xhtml_1_0_end_select_tag(Xhtml* xhtml, Node* child)
  * @return The conversion result is returned.
  */
 static char*
-xhtml_1_0_start_option_tag(Xhtml* xhtml, Node* child)
+s_xhtml_1_0_start_option_tag(xhtml_t* xhtml, Node* child)
 {
   Doc* doc = xhtml->doc;
   request_rec* r = doc->r;
@@ -1745,7 +1745,7 @@ xhtml_1_0_start_option_tag(Xhtml* xhtml, Node* child)
  * @return The conversion result is returned.
  */
 static char*
-xhtml_1_0_end_option_tag(Xhtml* xhtml, Node* child)
+s_xhtml_1_0_end_option_tag(xhtml_t* xhtml, Node* child)
 {
   Doc* doc = xhtml->doc;
   request_rec* r = doc->r;
@@ -1764,7 +1764,7 @@ xhtml_1_0_end_option_tag(Xhtml* xhtml, Node* child)
  * @return The conversion result is returned.
  */
 static char*
-xhtml_1_0_start_div_tag(Xhtml* xhtml, Node* child)
+s_xhtml_1_0_start_div_tag(xhtml_t* xhtml, Node* child)
 {
   Doc* doc = xhtml->doc;
   request_rec* r = doc->r;
@@ -1806,7 +1806,7 @@ xhtml_1_0_start_div_tag(Xhtml* xhtml, Node* child)
  * @return The conversion result is returned.
  */
 static char*
-xhtml_1_0_end_div_tag(Xhtml* xhtml, Node* child)
+s_xhtml_1_0_end_div_tag(xhtml_t* xhtml, Node* child)
 {
   Doc* doc = xhtml->doc;
   request_rec* r = doc->r;
@@ -1816,8 +1816,15 @@ xhtml_1_0_end_div_tag(Xhtml* xhtml, Node* child)
   return xhtml->out;
 }
 
+/**
+ * It is a handler who processes the CHXJ:IF tag.
+ *
+ * @param xhtml  [i/o] The pointer to the XHTML structure at the output
+ *                     destination is specified.
+ * @param node   [i]   The CHXJ:IF tag node is specified.
+ */
 static void
-xhtml_1_0_chxjif_tag(Xhtml* xhtml, Node* node)
+s_xhtml_1_0_chxjif_tag(xhtml_t* xhtml, Node* node)
 {
   Doc*         doc   = xhtml->doc;
   Node*        child;
@@ -1828,7 +1835,7 @@ xhtml_1_0_chxjif_tag(Xhtml* xhtml, Node* node)
        child = qs_get_next_node(doc, child))
   {
     xhtml->out = apr_pstrcat(r->pool, xhtml->out, child->otext, NULL);
-    xhtml_1_0_chxjif_tag(xhtml, child);
+    s_xhtml_1_0_chxjif_tag(xhtml, child);
   }
 }
 /*
