@@ -101,27 +101,26 @@ chxj_exchange(request_rec *r, const char** src, apr_size_t* len)
   ap_log_rerror(APLOG_MARK,APLOG_DEBUG, 0, r, 
           "content type is %s", r->content_type);
 
-  if (strncmp(r->content_type, "text/html",   9) != 0)
-  {
-    ap_log_rerror(APLOG_MARK,APLOG_DEBUG, 0, r, "content type is %s", r->content_type);
+  if (*(char*)r->content_type == 't' 
+  && strncmp(r->content_type, "text/html",   9) != 0) {
+    ap_log_rerror(APLOG_MARK,APLOG_DEBUG, 
+      0, r, "content type is %s", r->content_type);
     return (char*)*src;
   }
 
-  if (!r->header_only) 
-  {
-    device_table *spec = chxj_specified_device(r, user_agent);
-    if (spec->html_spec_type == CHXJ_SPEC_Chtml_1_0) 
-    {
+  if (!r->header_only) {
+    device_table_t* spec = chxj_specified_device(r, user_agent);
+    if (spec->html_spec_type == CHXJ_SPEC_Chtml_1_0) {
       /*----------------------------------------------------------------------*/
       /* DoCoMo i-Mode 1.0                                                    */
       /*----------------------------------------------------------------------*/
-      ap_log_rerror(APLOG_MARK,APLOG_DEBUG, 0, r, "select DoCoMo i-Mode 1.0 ");
+      ap_log_rerror(
+        APLOG_MARK,APLOG_DEBUG, 0, r, "select DoCoMo i-Mode 1.0 ");
       dst = chxj_exchange_chtml10(r, spec, *src, *len, len);
 
     }
     else
-    if (spec->html_spec_type == CHXJ_SPEC_Chtml_2_0) 
-    {
+    if (spec->html_spec_type == CHXJ_SPEC_Chtml_2_0) {
       /*----------------------------------------------------------------------*/
       /* DoCoMo i-Mode 2.0                                                    */
       /*----------------------------------------------------------------------*/
@@ -129,8 +128,7 @@ chxj_exchange(request_rec *r, const char** src, apr_size_t* len)
       dst = chxj_exchange_chtml20(r, spec, *src, *len, len);
     }
     else 
-    if (spec->html_spec_type == CHXJ_SPEC_Chtml_3_0) 
-    {
+    if (spec->html_spec_type == CHXJ_SPEC_Chtml_3_0) {
       /*----------------------------------------------------------------------*/
       /* DoCoMo i-Mode 3.0                                                    */
       /*----------------------------------------------------------------------*/
@@ -138,8 +136,7 @@ chxj_exchange(request_rec *r, const char** src, apr_size_t* len)
       dst = chxj_exchange_chtml30(r, spec, *src, *len, len);
     }
     else
-    if (spec->html_spec_type == CHXJ_SPEC_Chtml_4_0) 
-    {
+    if (spec->html_spec_type == CHXJ_SPEC_Chtml_4_0) {
       /*----------------------------------------------------------------------*/
       /* DoCoMo i-Mode 4.0                                                    */
       /*----------------------------------------------------------------------*/
@@ -147,8 +144,7 @@ chxj_exchange(request_rec *r, const char** src, apr_size_t* len)
       dst = chxj_exchange_chtml30(r, spec, *src, *len, len);
     }
     else 
-    if (spec->html_spec_type == CHXJ_SPEC_Chtml_5_0) 
-    {
+    if (spec->html_spec_type == CHXJ_SPEC_Chtml_5_0) {
       /*----------------------------------------------------------------------*/
       /* DoCoMo i-Mode 5.0                                                    */
       /*----------------------------------------------------------------------*/
@@ -156,8 +152,7 @@ chxj_exchange(request_rec *r, const char** src, apr_size_t* len)
       dst = chxj_exchange_chtml30(r, spec, *src, *len, len);
     }
     else
-    if (spec->html_spec_type == CHXJ_SPEC_XHtml_Mobile_1_0) 
-    {
+    if (spec->html_spec_type == CHXJ_SPEC_XHtml_Mobile_1_0) {
       /*----------------------------------------------------------------------*/
       /* AU XHtml Mobile 1.0 (XHtml Basic 1.0 extended)                       */
       /*----------------------------------------------------------------------*/
@@ -165,8 +160,7 @@ chxj_exchange(request_rec *r, const char** src, apr_size_t* len)
       dst = chxj_exchange_xhtml_mobile_1_0(r, spec, *src, *len, len);
     }
     else
-    if (spec->html_spec_type == CHXJ_SPEC_Hdml) 
-    {
+    if (spec->html_spec_type == CHXJ_SPEC_Hdml) {
       /*----------------------------------------------------------------------*/
       /* AU HDML Version 3.0 Only                                             */
       /*----------------------------------------------------------------------*/
@@ -174,16 +168,14 @@ chxj_exchange(request_rec *r, const char** src, apr_size_t* len)
       dst = chxj_exchange_hdml(r, spec, *src, *len, len);
     }
     else
-    if (spec->html_spec_type == CHXJ_SPEC_Jhtml) 
-    {
+    if (spec->html_spec_type == CHXJ_SPEC_Jhtml) {
       /*----------------------------------------------------------------------*/
       /* J-Phone and Vodaphone                                                */
       /*----------------------------------------------------------------------*/
       ap_log_rerror(APLOG_MARK,APLOG_DEBUG, 0, r, "select JHTML");
       dst = chxj_exchange_jhtml(r, spec, *src, *len, len);
     }
-    else 
-    {
+    else {
       ap_log_rerror(APLOG_MARK,APLOG_DEBUG, 0, r, "select ?????");
       ap_log_rerror(APLOG_MARK,APLOG_DEBUG, 0, r, "html_spec_type[%d]", 
                       spec->html_spec_type);
@@ -193,14 +185,16 @@ chxj_exchange(request_rec *r, const char** src, apr_size_t* len)
 
   ap_log_rerror(APLOG_MARK,APLOG_DEBUG, 0, r, "end chxj_exchange()");
   ap_log_rerror(APLOG_MARK,APLOG_DEBUG, 0, r, "Length=[%d]", *len);
-  if (*len == 0)
-  {
+  if (*len == 0) {
     dst = apr_psprintf(r->pool, "\n");
     *len = 1;
   }
   dst[*len] = 0;
   return dst;
 }
+
+
+
 /**
  * It converts it from POSTDATA .
  *
@@ -226,21 +220,16 @@ chxj_input_exchange(request_rec *r, const char** src, apr_size_t* len)
   /* _chxj_c_ */
   /* _chxj_r_ */
   /* _chxj_s_ */
-  for (;;) 
-  {
+  for (;;) {
     pair = apr_strtok(s, "&", &pstate);
     if (pair == NULL)
-    {
       break;
-    } 
     s = NULL;
 
     name  = apr_strtok(pair, "=", &vstate);
     value = apr_strtok(NULL, "=", &vstate);
-    if (strncasecmp(name, "_chxj", 5) != 0) 
-    {
-      if (strlen(result) != 0)
-      {
+    if (strncasecmp(name, "_chxj", 5) != 0) {
+      if (strlen(result) != 0) {
         result = apr_pstrcat(r->pool, result, "&", NULL);
       }
       result = apr_pstrcat(r->pool, result, name, "=", value, NULL);
@@ -248,22 +237,16 @@ chxj_input_exchange(request_rec *r, const char** src, apr_size_t* len)
     else
     if (strncasecmp(name, "_chxj_c_", 8) == 0 
     ||  strncasecmp(name, "_chxj_r_", 8) == 0
-    ||  strncasecmp(name, "_chxj_s_", 8) == 0)
-    {
+    ||  strncasecmp(name, "_chxj_s_", 8) == 0) {
       if (value == NULL)
-      {
         continue;
-      }
 
       if (strlen(value) == 0)
-      {
         continue;
-      }
 
       if (strlen(result) != 0)
-      {
         result = apr_pstrcat(r->pool, result, "&", NULL);
-      }
+
       result = apr_pstrcat(r->pool, result, &name[8], "=", value, NULL);
     }
   }
@@ -299,8 +282,7 @@ pass_data_to_filter(ap_filter_t *f, const char *data,
   APR_BRIGADE_INSERT_TAIL(bb, b);
 
   rv = ap_pass_brigade(f->next, bb);
-  if (rv != APR_SUCCESS) 
-  {
+  if (rv != APR_SUCCESS) {
     ap_log_rerror(APLOG_MARK, APLOG_DEBUG, rv, r,
                    "ap_pass_brigade()");
     return rv;
@@ -324,117 +306,104 @@ chxj_output_filter(ap_filter_t *f, apr_bucket_brigade *bb)
   const char*  data;
   char*       contentLength;
   apr_size_t  len;
-  mod_chxj_ctx* ctx;
+  mod_chxj_ctx_t* ctx;
 
 
   ap_log_rerror(APLOG_MARK, APLOG_DEBUG, 0, r, 
           "start of chxj_output_filter()");
-  if (!f->ctx) 
-  {
+  if (!f->ctx) {
     if ((f->r->proto_num >= 1001) 
     &&  !f->r->main 
     &&  !f->r->prev) 
-    {
       f->r->chunked = 1;
-    }
   }
 
 
   for (b = APR_BRIGADE_FIRST(bb);
        b != APR_BRIGADE_SENTINEL(bb); 
-       b = APR_BUCKET_NEXT(b)) 
-  {
-    if (APR_BUCKET_IS_EOS(b)) 
-    {
+       b = APR_BUCKET_NEXT(b)) {
+    if (APR_BUCKET_IS_EOS(b)) {
       ap_log_rerror(APLOG_MARK, APLOG_DEBUG, 0, r, "eos");
       /*----------------------------------------------------------------------*/
       /* End Of File                                                          */
       /*----------------------------------------------------------------------*/
-      if (f->ctx) 
-      {
-        ctx = (mod_chxj_ctx*)f->ctx;
-        if (strncmp(r->content_type, "text/html",   9) == 0)
-        {
-          if (ctx->len)
-          {
+      if (f->ctx) {
+        ctx = (mod_chxj_ctx_t*)f->ctx;
+        if (*(char*)r->content_type == 't' 
+        && strncmp(r->content_type, "text/html",   9) == 0) {
+          if (ctx->len) {
             char* tmp = apr_palloc(r->pool, ctx->len + 1);
             memset(tmp, 0, ctx->len + 1);
             memcpy(tmp, ctx->buffer, ctx->len);
-            ap_log_rerror(APLOG_MARK, APLOG_DEBUG, 0, r, "input data=[%s]", tmp);
+            ap_log_rerror(
+              APLOG_MARK, APLOG_DEBUG, 0, r, "input data=[%s]", tmp);
             ctx->buffer = chxj_exchange(r, (const char**)&tmp, (apr_size_t*)&ctx->len);
             ap_log_rerror(APLOG_MARK, APLOG_DEBUG, 0, r, "output data=[%.*s]", ctx->len,ctx->buffer);
           }
-          else 
-          {
+          else {
             ctx->buffer = apr_psprintf(r->pool, "\n");
             ctx->len += 1;
           }
         }
-        if (strncmp(r->content_type, "image/", 6) == 0)
-        {
-          if (ctx->len)
-          {
+        if (*(char*)r->content_type == 'i' && 
+        strncmp(r->content_type, "image/", 6) == 0) {
+          if (ctx->len) {
             char* tmp = apr_palloc(r->pool, ctx->len + 1);
             memset(tmp, 0, ctx->len + 1);
             memcpy(tmp, ctx->buffer, ctx->len);
-            ap_log_rerror(APLOG_MARK, APLOG_DEBUG, 0, r, "input data=[%s]", tmp);
-            ctx->buffer = chxj_exchange_image(r, (const char**)&tmp, (apr_size_t*)&ctx->len);
-            ap_log_rerror(APLOG_MARK, APLOG_DEBUG, 0, r, "output data=[%.*s]", ctx->len,ctx->buffer);
+            ap_log_rerror(
+              APLOG_MARK, APLOG_DEBUG, 0, r, "input data=[%s]", tmp);
+            ctx->buffer = 
+              chxj_exchange_image(r, (const char**)&tmp,(apr_size_t*)&ctx->len);
+            ap_log_rerror(
+              APLOG_MARK, APLOG_DEBUG, 0, r, "output data=[%.*s]", ctx->len,ctx->buffer);
           }
         }
         contentLength = apr_psprintf(r->pool, "%d", ctx->len);
         apr_table_setn(r->headers_out, "Content-Length", contentLength);
         
-        if (ctx->len > 0)
-        {
+        if (ctx->len > 0) {
           rv = pass_data_to_filter(f, (const char*)ctx->buffer, (apr_size_t)ctx->len);
         }
         f->ctx = NULL;
         return rv;
       }
-      else
-      {
+      else {
         apr_table_setn(r->headers_out, "Content-Length", "0");
         rv = pass_data_to_filter(f, (const char*)"", (apr_size_t)0);
         return rv;
       }
     }
     else
-    if (apr_bucket_read(b, &data, &len, APR_BLOCK_READ) == APR_SUCCESS) 
-    {
+    if (apr_bucket_read(b, &data, &len, APR_BLOCK_READ) == APR_SUCCESS) {
       ap_log_rerror(APLOG_MARK, APLOG_DEBUG, 0, r, "read data[%.*s]",len, data);
 
-      if (f->ctx == NULL) 
-      {
+      if (f->ctx == NULL) {
         /*--------------------------------------------------------------------*/
         /* Start                                                              */
         /*--------------------------------------------------------------------*/
         ap_log_rerror(APLOG_MARK, APLOG_DEBUG, 0, r, "new context");
-        ctx = (mod_chxj_ctx*)apr_palloc(r->pool, sizeof(mod_chxj_ctx));
-        if (len > 0)
-        {
+        ctx = (mod_chxj_ctx_t*)apr_palloc(r->pool, sizeof(mod_chxj_ctx_t));
+        if (len > 0) {
           ctx->buffer = apr_palloc(r->pool, len);
           memcpy(ctx->buffer, data, len);
         }
-        else 
-        {
+        else {
           ctx->buffer = apr_palloc(r->pool, 1);
           ctx->buffer = '\0';
         }
         ctx->len = len;
         f->ctx = (void*)ctx;
       }
-      else 
-      {
+      else {
         /*--------------------------------------------------------------------*/
         /* append data                                                        */
         /*--------------------------------------------------------------------*/
         char* tmp;
         ap_log_rerror(APLOG_MARK, APLOG_DEBUG, 0, r, "append data start");
-        ctx = (mod_chxj_ctx*)f->ctx;
+        ctx = (mod_chxj_ctx_t*)f->ctx;
 
-        if (len > 0)
-        {
+        if (len > 0) {
           tmp = apr_palloc(r->pool, ctx->len);
           memcpy(tmp, ctx->buffer, ctx->len);
           ctx->buffer = apr_palloc(r->pool, ctx->len + len);
@@ -495,25 +464,21 @@ chxj_input_filter(ap_filter_t*        f,
   obb = apr_brigade_create(r->pool, c->bucket_alloc);
 
   rv = ap_get_brigade(f->next, ibb, mode, block, readbytes);
-  if (rv != APR_SUCCESS)
-  {
+  if (rv != APR_SUCCESS) {
     ap_log_rerror(APLOG_MARK, APLOG_DEBUG, rv, r,
                     "ap_get_brigade() failed");
     return rv;
   }
 
-  APR_BRIGADE_FOREACH(b, ibb) 
-  {
+  APR_BRIGADE_FOREACH(b, ibb) {
     rv = apr_bucket_read(b, &data, &len, APR_BLOCK_READ);
-    if (rv != APR_SUCCESS) 
-    {
+    if (rv != APR_SUCCESS) {
       ap_log_rerror(APLOG_MARK, APLOG_ERR, rv, r,
                      "apr_bucket_read() failed");
       return rv;
     }
 
-    if (data != NULL)
-    {
+    if (data != NULL) {
       data_bucket = apr_palloc(r->pool, len+1);
       memset((void*)data_bucket, 0, len+1);
       memcpy(data_bucket, data, len);
@@ -522,16 +487,14 @@ chxj_input_filter(ap_filter_t*        f,
       data_brigade = apr_pstrcat(r->pool, data_brigade, data_bucket, NULL);
     }
 
-    if (APR_BUCKET_IS_EOS(b)) 
-    {
+    if (APR_BUCKET_IS_EOS(b)) {
       break;
     }
   }
   apr_brigade_cleanup(ibb);
 
   len = strlen(data_brigade);
-  if (len == 0)
-  {
+  if (len == 0) {
     ap_log_rerror(APLOG_MARK, APLOG_DEBUG, rv, r,
                     "data_brigade length is 0");
     ap_log_rerror(APLOG_MARK, APLOG_DEBUG, 0, r, "end of chxj_input_filter()");
@@ -540,8 +503,7 @@ chxj_input_filter(ap_filter_t*        f,
   }
   data_brigade = chxj_input_exchange(r, (const char**)&data_brigade, (apr_size_t*)&len);
 
-  if (len > 0)
-  {
+  if (len > 0) {
     ap_log_rerror(APLOG_MARK, APLOG_DEBUG, 0, f->r, "(in:exchange)POSTDATA:[%s]", data_brigade);
 
     obb = apr_brigade_create(r->pool, c->bucket_alloc);
@@ -566,7 +528,7 @@ apr_status_t
 chxj_init_module_kill(void *data)
 {
   server_rec *base_server = (server_rec *)data;
-  mod_chxj_global_config* conf;
+  mod_chxj_global_config_t* conf;
 
   ap_log_error(APLOG_MARK, APLOG_DEBUG, 0, base_server, 
                   "start chxj_init_module_kill()");
@@ -581,10 +543,11 @@ chxj_init_module_kill(void *data)
   return APR_SUCCESS;
 }
 
-static mod_chxj_global_config*
+
+static mod_chxj_global_config_t*
 chxj_global_config_create(apr_pool_t* pool, server_rec* s)
 {
-  mod_chxj_global_config* conf;
+  mod_chxj_global_config_t* conf;
   void*           param;
 
   ap_log_error(APLOG_MARK, APLOG_DEBUG, 0, s,
@@ -592,12 +555,11 @@ chxj_global_config_create(apr_pool_t* pool, server_rec* s)
 
 
   apr_pool_userdata_get(&param, CHXJ_MOD_CONFIG_KEY, pool);
-  conf = (mod_chxj_global_config*)param;
+  conf = (mod_chxj_global_config_t*)param;
   apr_pool_cleanup_register(pool, s,
                                chxj_init_module_kill,
                                apr_pool_cleanup_null);
-  if (conf)
-  {
+  if (conf) {
     /*------------------------------------------------------------------------*/
     /* reused for lifetime of the server                                      */
     /*------------------------------------------------------------------------*/
@@ -609,8 +571,8 @@ chxj_global_config_create(apr_pool_t* pool, server_rec* s)
   /*--------------------------------------------------------------------------*/
   /* allocate an own subpool which survives server restarts                   */
   /*--------------------------------------------------------------------------*/
-  conf = (mod_chxj_global_config*)apr_palloc(pool, 
-                  sizeof(mod_chxj_global_config));
+  conf = (mod_chxj_global_config_t*)apr_palloc(pool, 
+                  sizeof(mod_chxj_global_config_t));
   conf->client_shm  = NULL;
   conf->client_lock = NULL;
   memset(conf->client_lock_file_name, 0, sizeof(conf->client_lock_file_name));
@@ -650,7 +612,7 @@ chxj_init_module(apr_pool_t *p,
 static void*
 chxj_config_server_create(apr_pool_t *p, server_rec *s)
 {
-  mod_chxj_global_config *gc;
+  mod_chxj_global_config_t *gc;
 
   gc = chxj_global_config_create(p,s);
 
@@ -700,9 +662,9 @@ chxj_register_hooks(apr_pool_t *p)
 static void* 
 chxj_create_per_dir_config(apr_pool_t *p, char *arg) 
 {
-  mod_chxj_config* conf;
+  mod_chxj_config_t* conf;
 
-  conf = apr_pcalloc(p, sizeof(mod_chxj_config));
+  conf = apr_pcalloc(p, sizeof(mod_chxj_config_t));
   conf->device_data_file = NULL;
   conf->devices          = NULL;
   conf->emoji_data_file  = NULL;
@@ -721,9 +683,9 @@ chxj_create_per_dir_config(apr_pool_t *p, char *arg)
 static void*
 chxj_merge_per_dir_config(apr_pool_t *p, void *basev, void *addv)
 {
-  mod_chxj_config *base = (mod_chxj_config*)basev;
-  mod_chxj_config *add  = (mod_chxj_config*)addv;
-  mod_chxj_config *mrg  = (mod_chxj_config*)apr_palloc(p, sizeof(mod_chxj_config));
+  mod_chxj_config_t *base = (mod_chxj_config_t*)basev;
+  mod_chxj_config_t *add  = (mod_chxj_config_t*)addv;
+  mod_chxj_config_t *mrg  = (mod_chxj_config_t*)apr_palloc(p, sizeof(mod_chxj_config_t));
 
   mrg->device_data_file = NULL;
   mrg->devices          = NULL;
@@ -733,55 +695,46 @@ chxj_merge_per_dir_config(apr_pool_t *p, void *basev, void *addv)
   mrg->image_copyright  = NULL;
   mrg->emoji            = NULL;
   mrg->emoji_tail       = NULL;
-  if (add->device_data_file == NULL)
-  {
+
+  if (! add->device_data_file) {
     mrg->devices = base->devices;
     mrg->device_data_file = apr_pstrdup(p, base->device_data_file);
   }
-  else
-  {
+  else {
     mrg->devices = add->devices;
     mrg->device_data_file = apr_pstrdup(p, add->device_data_file);
   }
 
-  if (add->emoji_data_file == NULL)
-  {
+  if (! add->emoji_data_file) {
     mrg->emoji = base->emoji;
     mrg->emoji_tail = base->emoji_tail;
     mrg->emoji_data_file = apr_pstrdup(p, base->emoji_data_file);
   }
-  else
-  {
+  else {
     mrg->emoji = add->emoji;
     mrg->emoji_tail = add->emoji_tail;
     mrg->emoji_data_file = apr_pstrdup(p, add->emoji_data_file);
   }
 
-  if (add->image == CHXJ_IMG_OFF)
-  {
+  if (add->image == CHXJ_IMG_OFF) {
     mrg->image = base->image;
   }
-  else
-  {
+  else {
     mrg->image = add->image;
   }
 
-  if (strcasecmp(add->image_cache_dir ,DEFAULT_IMAGE_CACHE_DIR)==0)
-  {
+  if (strcasecmp(add->image_cache_dir ,DEFAULT_IMAGE_CACHE_DIR)==0) {
     mrg->image_cache_dir = apr_pstrdup(p, base->image_cache_dir);
   }
-  else
-  {
+  else {
     mrg->image_cache_dir = apr_pstrdup(p, add->image_cache_dir);
   }
 
-  if (add->image_copyright == NULL && base->image_copyright != NULL)
-  {
+  if (add->image_copyright == NULL && base->image_copyright != NULL) {
     mrg->image_copyright = apr_pstrdup(p, base->image_copyright);
   }
   else
-  if (add->image_copyright != NULL)
-  {
+  if (add->image_copyright != NULL) {
     mrg->image_copyright = apr_pstrdup(p, add->image_copyright);
   }
   return mrg;
@@ -796,7 +749,7 @@ chxj_merge_per_dir_config(apr_pool_t *p, void *basev, void *addv)
 static const char* 
 cmd_load_device_data(cmd_parms *parms, void *mconfig, const char* arg) 
 {
-  mod_chxj_config* conf;
+  mod_chxj_config_t* conf;
   Doc doc;
   doc.r = NULL;
   if (strlen(arg) > 256) 
@@ -804,7 +757,7 @@ cmd_load_device_data(cmd_parms *parms, void *mconfig, const char* arg)
     return "device data filename too long.";
   }
 
-  conf = (mod_chxj_config*)mconfig;
+  conf = (mod_chxj_config_t*)mconfig;
   conf->device_data_file = apr_pstrdup(parms->pool, arg);
 
   qs_init_malloc(&doc);
@@ -827,7 +780,7 @@ cmd_load_device_data(cmd_parms *parms, void *mconfig, const char* arg)
 static const char* 
 cmd_load_emoji_data(cmd_parms *parms, void *mconfig, const char* arg) 
 {
-  mod_chxj_config* conf;
+  mod_chxj_config_t* conf;
   char* rtn;
   Doc doc;
   doc.r = NULL;
@@ -837,7 +790,7 @@ cmd_load_emoji_data(cmd_parms *parms, void *mconfig, const char* arg)
     return "emoji data filename too long.";
   }
 
-  conf = (mod_chxj_config*)mconfig;
+  conf = (mod_chxj_config_t*)mconfig;
   conf->emoji_data_file = apr_pstrdup(parms->pool, arg);
   qs_init_malloc(&doc);
   qs_init_root_node(&doc);
@@ -852,7 +805,7 @@ cmd_load_emoji_data(cmd_parms *parms, void *mconfig, const char* arg)
 static const char* 
 cmd_set_image_engine(cmd_parms *parms, void *mconfig, const char* arg) 
 {
-  mod_chxj_config* conf;
+  mod_chxj_config_t* conf;
   Doc doc;
   doc.r = NULL;
   if (strlen(arg) > 256) 
@@ -860,7 +813,7 @@ cmd_set_image_engine(cmd_parms *parms, void *mconfig, const char* arg)
     return "image uri is too long.";
   }
 
-  conf = (mod_chxj_config*)mconfig;
+  conf = (mod_chxj_config_t*)mconfig;
   if (strcasecmp("ON", arg) == 0)
   {
     conf->image = CHXJ_IMG_ON;
@@ -875,7 +828,7 @@ cmd_set_image_engine(cmd_parms *parms, void *mconfig, const char* arg)
 static const char* 
 cmd_set_image_cache_dir(cmd_parms *parms, void *mconfig, const char* arg) 
 {
-  mod_chxj_config* conf;
+  mod_chxj_config_t* conf;
   Doc doc;
   doc.r = NULL;
   if (strlen(arg) > 256) 
@@ -883,7 +836,7 @@ cmd_set_image_cache_dir(cmd_parms *parms, void *mconfig, const char* arg)
     return "cache dir name is too long.";
   }
 
-  conf = (mod_chxj_config*)mconfig;
+  conf = (mod_chxj_config_t*)mconfig;
   conf->image_cache_dir = apr_pstrdup(parms->pool, arg);
   return NULL;
 }
@@ -891,7 +844,7 @@ cmd_set_image_cache_dir(cmd_parms *parms, void *mconfig, const char* arg)
 static const char* 
 cmd_set_image_copyright(cmd_parms *parms, void *mconfig, const char* arg) 
 {
-  mod_chxj_config* conf;
+  mod_chxj_config_t* conf;
   Doc doc;
 
   doc.r = NULL;
@@ -900,7 +853,7 @@ cmd_set_image_copyright(cmd_parms *parms, void *mconfig, const char* arg)
     return "Copyright Flag is too long.";
   }
 
-  conf = (mod_chxj_config*)mconfig;
+  conf = (mod_chxj_config_t*)mconfig;
   conf->image_copyright = apr_pstrdup(parms->pool, arg);
   return NULL;
 }
